using System;
using System.IO;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Globalization;
using System.Drawing.Imaging;
using System.Drawing.Drawing2D;
using CADImport;
using CADImport.RasterImage;
using CADImport.FaceModule;
using CADImport.HPGL2;
using CADImport.Printing;
using CADImport.CADImportForms;
using CADImport.Export.DirectCADtoDXF;

namespace CADImportNetDemos.CADViewerDemo
{
	#region Help
	/// <summary>
	/// Represents the main application form of the viewer in which CAD files can be opened and viewed.
	/// </summary>
	#endregion Help
	public class MainForm: System.Windows.Forms.Form
	{	
		private CADImport.CADImportForms.LayerForm lForm;
		private CADImport.CADImportForms.AboutForm aboutFrm;
		private CADImport.CADImportForms.SHXForm shxFrm;	
		#region protect
#if protect
		private CADImport.CADImportForms.RegForm regFrm;
#endif
		#endregion protect
		private CADImport.Printing.PrintingForm prtForm;
		private CADImport.CADImportForms.OptionsForm optForm;
		private CADImport.CADImportForms.SetRasterSizeForm rasterSizeForm;
		private CADImport.CADImportForms.OpenFileFromWebForm openFromWebForm;
		#region protect
#if (protect && floatprotect)
		private CADImport.CADImportForms.FloatLicForm floatLicFrm;
#endif
		#endregion		
	
		private System.Drawing.PointF old_Pos;												
		private System.Drawing.PointF pos;
		private System.Drawing.SizeF visibleArea;
		private float sc;
		private float prev_sc;	
		private int cX;		
		private int cY;		
		private bool detRMouseDown;								
		private bool drawMode;
		private bool showLineWeight;
		private bool useSelectEntity;
		private bool useSHXFonts;
		private bool textVisible;
		private bool dimVisible;
		private bool useWinEllipse;
		private bool useDoubleBuffering;		
		private int curLngIndex;
		private string lngFile;
		private System.Collections.SortedList settingsLst;
		private CADImport.CADImage cadImage;
		private CADImport.FaceModule.Orbit3D orb3D;	
		private CADImport.FaceModule.ClipRect clipRectangle;							
		private CADImport.FaceModule.MultipleLanguage mlng;
		private CADImport.FaceModule.SaveSettings svSet;
		private CADImport.FaceModule.ListItemSelectEventHandler listItemSelectDel;		
		private CADImport.FaceModule.CADPictureBox cadPictBox;			

		private static string openFileName;				
		private static readonly string fileSettingsName;																		

		private System.Windows.Forms.StatusBar stBar;
		private System.Windows.Forms.MainMenu mainMenu;
		private System.Windows.Forms.MenuItem mView;
		private System.Windows.Forms.StatusBarPanel sbOpen;
		private System.Windows.Forms.StatusBarPanel sbScale;
		private System.Windows.Forms.ToolBarButton tlbOpen;
		private System.Windows.Forms.ToolBarButton tlbZoomIn;
		private System.Windows.Forms.ToolBarButton tlbZoomOut;
		private System.Windows.Forms.ToolBarButton tlbSave;
		private System.Windows.Forms.ToolBarButton tlbWhite;
		private System.Windows.Forms.ToolBarButton tlbBlack;
		private System.Windows.Forms.ToolBarButton tlbColor;
		private System.Windows.Forms.ToolBar tlbTool;
		private System.Windows.Forms.ToolBarButton tlb3d; 
		private System.Windows.Forms.ToolBarButton tlbLay;
		private System.Windows.Forms.ToolBarButton tlbArcPoly;
		private System.Windows.Forms.ToolBarButton tlbBlackMode;
		private System.Windows.Forms.ToolBarButton tlbColorMode;
		private System.Windows.Forms.StatusBarPanel sbCoord;
		private System.Windows.Forms.ComboBox cbLayouts;
		private System.Windows.Forms.Panel pnlLayouts;
		private System.Windows.Forms.ToolBarButton tlbDefSize;
		private System.Windows.Forms.ToolBarButton tlbTextShow;
		private System.Windows.Forms.ToolBarButton tlbDimShow;
		private System.Windows.Forms.ToolBarButton tlbSaveImageClip;
		private System.Windows.Forms.ToolBarButton tlbPrint;
		private System.Windows.Forms.ToolBarButton tlbSHX;
		private System.Windows.Forms.Panel trvPanel;
		private System.ComponentModel.IContainer components;
		private System.Windows.Forms.MenuItem editMenuItem;
		private System.Windows.Forms.MenuItem cADFilesMenuItem; 
		private System.Windows.Forms.MenuItem helpMenuItem;
		private System.Windows.Forms.PrintPreviewDialog printPrevDlg;		
		private System.Windows.Forms.ToolBarButton tlbRect;
		private System.Windows.Forms.PropertyGrid propGrid;
		private System.Windows.Forms.TreeView trvEntity;		
		private System.Windows.Forms.ToolBarButton tlbSelObject;		
		private System.Windows.Forms.MenuItem miFloatLic;				
		private System.Windows.Forms.ToolBarButton tlbAxes;		
		private System.Windows.Forms.Splitter spTree;						
		private System.Windows.Forms.MenuItem miOpenFromWeb;
		private System.Windows.Forms.ToolBarButton tlbOpenFromClipboard;
		private System.Windows.Forms.ToolBarButton tlbUseDoubleBuffering;
		private System.Windows.Forms.ToolBarButton tlbRotateLeft;
		private System.Windows.Forms.ToolBarButton tlbRotateRight;
		private System.Windows.Forms.Label lbLayouts;
		private System.Windows.Forms.MenuItem miSeparator1;
		private System.Windows.Forms.MenuItem miSeparator2;
		private System.Windows.Forms.MenuItem miSeparator3;
		private System.Windows.Forms.MenuItem miSeparator4;
		private System.Windows.Forms.MenuItem miSeparator5;
		private System.Windows.Forms.MenuItem miLanguages;
		private System.Windows.Forms.MenuItem miRegistration;
		private System.Windows.Forms.MenuItem miFile;
		private System.Windows.Forms.MenuItem miOpenFile;
		private System.Windows.Forms.MenuItem miSaveFile;
		private System.Windows.Forms.MenuItem miSaveAsDXF;
		private System.Windows.Forms.MenuItem miPrint;
		private System.Windows.Forms.MenuItem miCustomPrint;
		private System.Windows.Forms.MenuItem miPrintPreview;
		private System.Windows.Forms.MenuItem miClosePicture;
		private System.Windows.Forms.MenuItem miExit;
		private System.Windows.Forms.MenuItem miCopyAsBMP;
		private System.Windows.Forms.MenuItem miShowEntityTree;
		private System.Windows.Forms.MenuItem miZoomIn;
		private System.Windows.Forms.MenuItem miZoomOut;
		private System.Windows.Forms.MenuItem miScale;
		private System.Windows.Forms.MenuItem miZoom10;
		private System.Windows.Forms.MenuItem miZoom25;
		private System.Windows.Forms.MenuItem miZoom50;
		private System.Windows.Forms.MenuItem miZoom100;
		private System.Windows.Forms.MenuItem miZoom200;
		private System.Windows.Forms.MenuItem miZoom400;
		private System.Windows.Forms.MenuItem miZoom800;
		private System.Windows.Forms.MenuItem miFitToWindow;
		private System.Windows.Forms.MenuItem miShowShxForm;
		private System.Windows.Forms.MenuItem miShowOptionsForm;
		private System.Windows.Forms.MenuItem miDrawNormalColor;
		private System.Windows.Forms.MenuItem miDrawBlackColor;
		private System.Windows.Forms.MenuItem miWhiteBackground;
		private System.Windows.Forms.MenuItem miBlackBackground;
		private System.Windows.Forms.MenuItem miChangeBackgroundColor;
		private System.Windows.Forms.MenuItem miShowLineWeight;
		private System.Windows.Forms.MenuItem miArcsSplit;
		private System.Windows.Forms.MenuItem miDimShow;
		private System.Windows.Forms.MenuItem miTextsShow;
		private System.Windows.Forms.MenuItem miLayersShow;
		private System.Windows.Forms.MenuItem mi3DViews;
		private System.Windows.Forms.MenuItem miInitialView;
		private System.Windows.Forms.MenuItem miTopView;
		private System.Windows.Forms.MenuItem miBottomView;
		private System.Windows.Forms.MenuItem miLeftView;
		private System.Windows.Forms.MenuItem miRightView;
		private System.Windows.Forms.MenuItem miFrontView;
		private System.Windows.Forms.MenuItem miBackView;
		private System.Windows.Forms.MenuItem miSWIsometricView;
		private System.Windows.Forms.MenuItem miSEIsometricView;
		private System.Windows.Forms.MenuItem miNEIsometricView;
		private System.Windows.Forms.MenuItem miNWIsometricView;
		private System.Windows.Forms.MenuItem miEnable3DOrbit;
		private System.Windows.Forms.MenuItem miAbout;
		private System.Windows.Forms.SaveFileDialog dlgSaveImg;
		private System.Windows.Forms.ColorDialog dlgSetColor;
		private System.Windows.Forms.ContextMenu menuOrbitView;
		private System.Windows.Forms.ImageList imgLstToolBtn;
		private System.Windows.Forms.SaveFileDialog dlgSaveDXF;
		private System.Windows.Forms.OpenFileDialog dlgOpenSerializeFile;
		private System.Windows.Forms.SaveFileDialog dlgSaveSerializeFile;
		private System.Windows.Forms.OpenFileDialog dlgOpenFile;
		private System.Windows.Forms.MenuItem miInitialOrbitView;
		private System.Windows.Forms.MenuItem miTopOrbitView;
		private System.Windows.Forms.MenuItem miBottomOrbitView;
		private System.Windows.Forms.MenuItem miLeftOrbitView;
		private System.Windows.Forms.MenuItem miRightOrbitView;
		private System.Windows.Forms.MenuItem miFrontOrbitView;
		private System.Windows.Forms.MenuItem miBackOrbitView;
		private System.Windows.Forms.MenuItem miSWOrbitView;
		private System.Windows.Forms.MenuItem miSEOrbitView;
		private System.Windows.Forms.MenuItem miNEOrbitView;
		private System.Windows.Forms.MenuItem miNWOrbitView;
		private System.Windows.Forms.Splitter spPropGrid;
		private System.Windows.Forms.ToolBarButton tlbRotateAngle;	
		
		#region Help
		#if RUSHELP
		/// <summary>
		///       
		/// </summary>
#else
		/// <summary>
		/// Gets or sets lines weight visibility
		/// </summary>
		#endif	
		#endregion
		public bool ShowLineWeight
		{
			get
			{
				return this.showLineWeight;
			}
			set
			{
				this.showLineWeight = value;				
			}
		}

		#region Help
		#if	RUSHELP
		/// <summary>
		///       - 
		/// (    true - )
		/// </summary>
		#else
		/// <summary>
		/// Gets or sets a flag of the drawing mode
		/// (if <b>true</b> - in color, else - in black-and-white)
		/// </summary>
		#endif
		#endregion
		public bool DrawMode
		{
			get
			{
				return this.drawMode;
			}
			set
			{				
				this.drawMode = value;
			}
		}

		#region Help
		#if RUSHELP
		/// <summary>
		///     <see cref="CADImport.FaceModule.MultipleLanguage"/>
		///   
		/// </summary>
		#else
		/// <summary>
		/// Gets or sets <see cref="CADImport.FaceModule.MultipleLanguage"/>MultipleLanguage object
		/// which defines application language
		/// </summary>
		#endif
		#endregion
		public CADImport.FaceModule.MultipleLanguage ApplicationLanguage
		{
			get
			{
				return this.mlng;
			}
			set
			{				
				this.mlng = value;
			}
		}

		#region Help
		/// <summary>
		/// Gets <see cref="CADImport.CADImage"/>CADImage object
		/// that corresponds the main class for reading/drawing
		/// viewing of cad file contents
		/// </summary>
		#endregion Help		
		public CADImage Image
		{
			get
			{
				return cadImage;
			}
			set
			{
				this.cadImage = value;
			}
		}

		#region Help
		/// <summary>
		/// An X coordinate of the last mouse click position on the screen.
		/// </summary>
		#endregion Help
		public int CurrentXClickPosition
		{
			get
			{
				return this.cX;
			}
		}
		#region Help
		/// <summary>
		/// A Y coordinate of the last mouse click position on the screen.
		/// </summary>
		#endregion Help
		public int CurrentYClickPosition
		{
			get
			{
				return this.cY;
			}
		}
		
		#region Help
		#if RUSHELP
		/// <summary>
		///      Orbit3D
		/// </summary>
		#else
		/// <summary>
		/// Gets or sets Orbit3D control
		/// </summary>
		#endif
		#endregion
		public Orbit3D Orb3D
		{
			get
			{
				return this.orb3D;
			}
			set
			{
				this.orb3D = value;
			}
		}

		#region Help
		/// <summary>
		/// A previous position of the current CAD image in relation to the top-left corner of the viewer.
		/// </summary>
		#endregion Help
		public PointF PreviousPosition
		{
			get
			{
				return this.old_Pos;
			}
			set
			{
				this.old_Pos = value;
			}
		}			
	
		#region Help
#if RUSHELP
		/// <summary>
		///      
		/// </summary>
#else		
		/// <summary>
		/// A position of the current CAD image in relation to the top-left corner of the viewer.
		/// </summary>		
#endif
		#endregion
		public PointF Position
		{
			get
			{
				return this.pos;
			}
			set
			{
				this.pos = value;
			}
		}

		#region Help
#if RUSHELP
		/// <summary>
		///         X
		/// </summary>
#else				
		/// <summary>
		/// Gets or sets a position of the drawing image by X axis
		/// </summary>
#endif
		#endregion
		public float LeftImagePosition
		{
			get
			{
				return this.pos.X;
			}
			set
			{
				this.pos.X = value;
			}
		}

		#region Help
#if RUSHELP
		/// <summary>
		///         Y
		/// </summary>
#else
		/// <summary>
		/// Gets or sets a position of the drawing image by Y axis
		/// </summary>
#endif
		#endregion
		public float TopImagePosition
		{
			get
			{
				return this.pos.Y;
			}
			set
			{
				this.pos.Y = value;
			}
		}

		#region Help
#if RUSHELP
		/// <summary>
		///        
		/// </summary>
#else
		/// <summary>
		/// Gets or sets base dimensions of the image drawing area
		/// </summary>
#endif
		#endregion
		public SizeF VisibleAreaSize
		{
			get
			{
				return this.visibleArea;
			}
			set
			{
				this.visibleArea = value;
			}
		}

		#region Help
		/// <summary>
		/// A scale in which the current CAD image is displayed in the viewer.
		/// </summary>
		#endregion Help
		public float ImageScale
		{
			get
			{
				return this.sc;
			}
			set
			{
				this.sc = value;
			}
		}

		#region Help
		/// <summary>
		/// A previous value of the scale in which the current CAD image is displayed in the viewer.
		/// </summary>
		#endregion Help
		public float ImagePreviousScale
		{
			get
			{
				return this.prev_sc;
			}
			set
			{
				this.prev_sc = value;
			}
		}

		#region Help
#if RUSHELP
		/// <summary>
		///       
		/// </summary>
#else
		/// <summary>
		/// Gets the current size and position of the drawing image
		/// </summary>
#endif
		#endregion
		public RectangleF ImageRectangleF
		{
			get
			{
				return new RectangleF(this.LeftImagePosition, this.TopImagePosition, 
									  VisibleAreaSize.Width * ImageScale, VisibleAreaSize.Height * ImageScale);								
			}
		}

		#region Help
#if RUSHELP
		/// <summary>
		///       
		/// </summary>
#else
		/// <summary>
		/// Gets the current size and position of the drawing image
		/// </summary>
#endif
		#endregion
		public DRect ImageDRect
		{
			get
			{
				return new DRect(this.LeftImagePosition, this.TopImagePosition, 
								 VisibleAreaSize.Width * ImageScale, VisibleAreaSize.Height * ImageScale);								
			}
		}
		
		static MainForm()
		{			
			fileSettingsName = Application.StartupPath + @"\Settings.txt";
			openFileName = string.Empty;
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.components = new System.ComponentModel.Container();
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(MainForm));
			this.dlgSaveImg = new System.Windows.Forms.SaveFileDialog();
			this.stBar = new System.Windows.Forms.StatusBar();
			this.sbOpen = new System.Windows.Forms.StatusBarPanel();
			this.sbScale = new System.Windows.Forms.StatusBarPanel();
			this.sbCoord = new System.Windows.Forms.StatusBarPanel();
			this.mainMenu = new System.Windows.Forms.MainMenu();
			this.miFile = new System.Windows.Forms.MenuItem();
			this.miOpenFile = new System.Windows.Forms.MenuItem();
			this.miOpenFromWeb = new System.Windows.Forms.MenuItem();
			this.miSaveFile = new System.Windows.Forms.MenuItem();
			this.miSaveAsDXF = new System.Windows.Forms.MenuItem();
			this.miPrint = new System.Windows.Forms.MenuItem();
			this.miCustomPrint = new System.Windows.Forms.MenuItem();
			this.miPrintPreview = new System.Windows.Forms.MenuItem();
			this.miClosePicture = new System.Windows.Forms.MenuItem();
			this.miSeparator1 = new System.Windows.Forms.MenuItem();
			this.miExit = new System.Windows.Forms.MenuItem();
			this.editMenuItem = new System.Windows.Forms.MenuItem();
			this.miCopyAsBMP = new System.Windows.Forms.MenuItem();
			this.mView = new System.Windows.Forms.MenuItem();
			this.miShowEntityTree = new System.Windows.Forms.MenuItem();
			this.miSeparator2 = new System.Windows.Forms.MenuItem();
			this.miZoomIn = new System.Windows.Forms.MenuItem();
			this.miZoomOut = new System.Windows.Forms.MenuItem();
			this.miScale = new System.Windows.Forms.MenuItem();
			this.miZoom10 = new System.Windows.Forms.MenuItem();
			this.miZoom25 = new System.Windows.Forms.MenuItem();
			this.miZoom50 = new System.Windows.Forms.MenuItem();
			this.miZoom100 = new System.Windows.Forms.MenuItem();
			this.miZoom200 = new System.Windows.Forms.MenuItem();
			this.miZoom400 = new System.Windows.Forms.MenuItem();
			this.miZoom800 = new System.Windows.Forms.MenuItem();
			this.miFitToWindow = new System.Windows.Forms.MenuItem();
			this.miSeparator3 = new System.Windows.Forms.MenuItem();
			this.miShowShxForm = new System.Windows.Forms.MenuItem();
			this.miShowOptionsForm = new System.Windows.Forms.MenuItem();
			this.cADFilesMenuItem = new System.Windows.Forms.MenuItem();
			this.miDrawNormalColor = new System.Windows.Forms.MenuItem();
			this.miDrawBlackColor = new System.Windows.Forms.MenuItem();
			this.miWhiteBackground = new System.Windows.Forms.MenuItem();
			this.miBlackBackground = new System.Windows.Forms.MenuItem();
			this.miChangeBackgroundColor = new System.Windows.Forms.MenuItem();
			this.miSeparator4 = new System.Windows.Forms.MenuItem();
			this.miShowLineWeight = new System.Windows.Forms.MenuItem();
			this.miArcsSplit = new System.Windows.Forms.MenuItem();
			this.miDimShow = new System.Windows.Forms.MenuItem();
			this.miTextsShow = new System.Windows.Forms.MenuItem();
			this.miSeparator5 = new System.Windows.Forms.MenuItem();
			this.miLayersShow = new System.Windows.Forms.MenuItem();
			this.mi3DViews = new System.Windows.Forms.MenuItem();
			this.miInitialView = new System.Windows.Forms.MenuItem();
			this.miTopView = new System.Windows.Forms.MenuItem();
			this.miBottomView = new System.Windows.Forms.MenuItem();
			this.miLeftView = new System.Windows.Forms.MenuItem();
			this.miRightView = new System.Windows.Forms.MenuItem();
			this.miFrontView = new System.Windows.Forms.MenuItem();
			this.miBackView = new System.Windows.Forms.MenuItem();
			this.miSWIsometricView = new System.Windows.Forms.MenuItem();
			this.miSEIsometricView = new System.Windows.Forms.MenuItem();
			this.miNEIsometricView = new System.Windows.Forms.MenuItem();
			this.miNWIsometricView = new System.Windows.Forms.MenuItem();
			this.miEnable3DOrbit = new System.Windows.Forms.MenuItem();
			this.helpMenuItem = new System.Windows.Forms.MenuItem();
			this.miLanguages = new System.Windows.Forms.MenuItem();
			this.miRegistration = new System.Windows.Forms.MenuItem();
			this.miFloatLic = new System.Windows.Forms.MenuItem();
			this.miAbout = new System.Windows.Forms.MenuItem();
			this.dlgSetColor = new System.Windows.Forms.ColorDialog();
			this.tlbTool = new System.Windows.Forms.ToolBar();
			this.tlbOpen = new System.Windows.Forms.ToolBarButton();
			this.tlbZoomIn = new System.Windows.Forms.ToolBarButton();
			this.tlbZoomOut = new System.Windows.Forms.ToolBarButton();
			this.tlbSave = new System.Windows.Forms.ToolBarButton();
			this.tlbWhite = new System.Windows.Forms.ToolBarButton();
			this.tlbBlack = new System.Windows.Forms.ToolBarButton();
			this.tlbColor = new System.Windows.Forms.ToolBarButton();
			this.tlb3d = new System.Windows.Forms.ToolBarButton();
			this.menuOrbitView = new System.Windows.Forms.ContextMenu();
			this.miInitialOrbitView = new System.Windows.Forms.MenuItem();
			this.miTopOrbitView = new System.Windows.Forms.MenuItem();
			this.miBottomOrbitView = new System.Windows.Forms.MenuItem();
			this.miLeftOrbitView = new System.Windows.Forms.MenuItem();
			this.miRightOrbitView = new System.Windows.Forms.MenuItem();
			this.miFrontOrbitView = new System.Windows.Forms.MenuItem();
			this.miBackOrbitView = new System.Windows.Forms.MenuItem();
			this.miSWOrbitView = new System.Windows.Forms.MenuItem();
			this.miSEOrbitView = new System.Windows.Forms.MenuItem();
			this.miNEOrbitView = new System.Windows.Forms.MenuItem();
			this.miNWOrbitView = new System.Windows.Forms.MenuItem();
			this.tlbRotateLeft = new System.Windows.Forms.ToolBarButton();
			this.tlbRotateRight = new System.Windows.Forms.ToolBarButton();
			this.tlbRotateAngle = new System.Windows.Forms.ToolBarButton();
			this.tlbLay = new System.Windows.Forms.ToolBarButton();
			this.tlbArcPoly = new System.Windows.Forms.ToolBarButton();
			this.tlbBlackMode = new System.Windows.Forms.ToolBarButton();
			this.tlbColorMode = new System.Windows.Forms.ToolBarButton();
			this.tlbDefSize = new System.Windows.Forms.ToolBarButton();
			this.tlbTextShow = new System.Windows.Forms.ToolBarButton();
			this.tlbDimShow = new System.Windows.Forms.ToolBarButton();
			this.tlbSaveImageClip = new System.Windows.Forms.ToolBarButton();
			this.tlbPrint = new System.Windows.Forms.ToolBarButton();
			this.tlbSHX = new System.Windows.Forms.ToolBarButton();
			this.tlbRect = new System.Windows.Forms.ToolBarButton();
			this.tlbSelObject = new System.Windows.Forms.ToolBarButton();
			this.tlbAxes = new System.Windows.Forms.ToolBarButton();
			this.tlbOpenFromClipboard = new System.Windows.Forms.ToolBarButton();
			this.tlbUseDoubleBuffering = new System.Windows.Forms.ToolBarButton();
			this.imgLstToolBtn = new System.Windows.Forms.ImageList(this.components);
			this.pnlLayouts = new System.Windows.Forms.Panel();
			this.lbLayouts = new System.Windows.Forms.Label();
			this.cbLayouts = new System.Windows.Forms.ComboBox();
			this.trvPanel = new System.Windows.Forms.Panel();
			this.trvEntity = new System.Windows.Forms.TreeView();
			this.spPropGrid = new System.Windows.Forms.Splitter();
			this.propGrid = new System.Windows.Forms.PropertyGrid();
			this.spTree = new System.Windows.Forms.Splitter();
			this.printPrevDlg = new System.Windows.Forms.PrintPreviewDialog();
			this.dlgSaveDXF = new System.Windows.Forms.SaveFileDialog();
			this.cadPictBox = new CADImport.FaceModule.CADPictureBox();
			this.dlgOpenSerializeFile = new System.Windows.Forms.OpenFileDialog();
			this.dlgSaveSerializeFile = new System.Windows.Forms.SaveFileDialog();
			this.dlgOpenFile = new System.Windows.Forms.OpenFileDialog();
			((System.ComponentModel.ISupportInitialize)(this.sbOpen)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.sbScale)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.sbCoord)).BeginInit();
			this.pnlLayouts.SuspendLayout();
			this.trvPanel.SuspendLayout();
			this.SuspendLayout();
			// 
			// dlgSaveImg
			// 
			this.dlgSaveImg.Filter = resources.GetString("dlgSaveImg.Filter");
			this.dlgSaveImg.RestoreDirectory = true;
			this.dlgSaveImg.Title = resources.GetString("dlgSaveImg.Title");
			// 
			// stBar
			// 
			this.stBar.AccessibleDescription = resources.GetString("stBar.AccessibleDescription");
			this.stBar.AccessibleName = resources.GetString("stBar.AccessibleName");
			this.stBar.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("stBar.Anchor")));
			this.stBar.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("stBar.BackgroundImage")));
			this.stBar.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("stBar.Dock")));
			this.stBar.Enabled = ((bool)(resources.GetObject("stBar.Enabled")));
			this.stBar.Font = ((System.Drawing.Font)(resources.GetObject("stBar.Font")));
			this.stBar.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("stBar.ImeMode")));
			this.stBar.Location = ((System.Drawing.Point)(resources.GetObject("stBar.Location")));
			this.stBar.Name = "stBar";
			this.stBar.Panels.AddRange(new System.Windows.Forms.StatusBarPanel[] {
																					 this.sbOpen,
																					 this.sbScale,
																					 this.sbCoord});
			this.stBar.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("stBar.RightToLeft")));
			this.stBar.ShowPanels = true;
			this.stBar.Size = ((System.Drawing.Size)(resources.GetObject("stBar.Size")));
			this.stBar.TabIndex = ((int)(resources.GetObject("stBar.TabIndex")));
			this.stBar.Text = resources.GetString("stBar.Text");
			this.stBar.Visible = ((bool)(resources.GetObject("stBar.Visible")));
			// 
			// sbOpen
			// 
			this.sbOpen.Alignment = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("sbOpen.Alignment")));
			this.sbOpen.AutoSize = System.Windows.Forms.StatusBarPanelAutoSize.Contents;
			this.sbOpen.Icon = ((System.Drawing.Icon)(resources.GetObject("sbOpen.Icon")));
			this.sbOpen.MinWidth = ((int)(resources.GetObject("sbOpen.MinWidth")));
			this.sbOpen.Text = resources.GetString("sbOpen.Text");
			this.sbOpen.ToolTipText = resources.GetString("sbOpen.ToolTipText");
			this.sbOpen.Width = ((int)(resources.GetObject("sbOpen.Width")));
			// 
			// sbScale
			// 
			this.sbScale.Alignment = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("sbScale.Alignment")));
			this.sbScale.AutoSize = System.Windows.Forms.StatusBarPanelAutoSize.Contents;
			this.sbScale.Icon = ((System.Drawing.Icon)(resources.GetObject("sbScale.Icon")));
			this.sbScale.MinWidth = ((int)(resources.GetObject("sbScale.MinWidth")));
			this.sbScale.Text = resources.GetString("sbScale.Text");
			this.sbScale.ToolTipText = resources.GetString("sbScale.ToolTipText");
			this.sbScale.Width = ((int)(resources.GetObject("sbScale.Width")));
			// 
			// sbCoord
			// 
			this.sbCoord.Alignment = ((System.Windows.Forms.HorizontalAlignment)(resources.GetObject("sbCoord.Alignment")));
			this.sbCoord.AutoSize = System.Windows.Forms.StatusBarPanelAutoSize.Contents;
			this.sbCoord.Icon = ((System.Drawing.Icon)(resources.GetObject("sbCoord.Icon")));
			this.sbCoord.MinWidth = ((int)(resources.GetObject("sbCoord.MinWidth")));
			this.sbCoord.Text = resources.GetString("sbCoord.Text");
			this.sbCoord.ToolTipText = resources.GetString("sbCoord.ToolTipText");
			this.sbCoord.Width = ((int)(resources.GetObject("sbCoord.Width")));
			// 
			// mainMenu
			// 
			this.mainMenu.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					 this.miFile,
																					 this.editMenuItem,
																					 this.mView,
																					 this.cADFilesMenuItem,
																					 this.helpMenuItem});
			this.mainMenu.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("mainMenu.RightToLeft")));
			// 
			// miFile
			// 
			this.miFile.Enabled = ((bool)(resources.GetObject("miFile.Enabled")));
			this.miFile.Index = 0;
			this.miFile.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																				   this.miOpenFile,
																				   this.miOpenFromWeb,
																				   this.miSaveFile,
																				   this.miSaveAsDXF,
																				   this.miPrint,
																				   this.miCustomPrint,
																				   this.miPrintPreview,
																				   this.miClosePicture,
																				   this.miSeparator1,
																				   this.miExit});
			this.miFile.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miFile.Shortcut")));
			this.miFile.ShowShortcut = ((bool)(resources.GetObject("miFile.ShowShortcut")));
			this.miFile.Text = resources.GetString("miFile.Text");
			this.miFile.Visible = ((bool)(resources.GetObject("miFile.Visible")));
			// 
			// miOpenFile
			// 
			this.miOpenFile.Enabled = ((bool)(resources.GetObject("miOpenFile.Enabled")));
			this.miOpenFile.Index = 0;
			this.miOpenFile.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miOpenFile.Shortcut")));
			this.miOpenFile.ShowShortcut = ((bool)(resources.GetObject("miOpenFile.ShowShortcut")));
			this.miOpenFile.Text = resources.GetString("miOpenFile.Text");
			this.miOpenFile.Visible = ((bool)(resources.GetObject("miOpenFile.Visible")));
			this.miOpenFile.Click += new System.EventHandler(this.miOpenFile_Click);
			// 
			// miOpenFromWeb
			// 
			this.miOpenFromWeb.Enabled = ((bool)(resources.GetObject("miOpenFromWeb.Enabled")));
			this.miOpenFromWeb.Index = 1;
			this.miOpenFromWeb.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miOpenFromWeb.Shortcut")));
			this.miOpenFromWeb.ShowShortcut = ((bool)(resources.GetObject("miOpenFromWeb.ShowShortcut")));
			this.miOpenFromWeb.Text = resources.GetString("miOpenFromWeb.Text");
			this.miOpenFromWeb.Visible = ((bool)(resources.GetObject("miOpenFromWeb.Visible")));
			this.miOpenFromWeb.Click += new System.EventHandler(this.miOpenFromWeb_Click);
			// 
			// miSaveFile
			// 
			this.miSaveFile.Enabled = ((bool)(resources.GetObject("miSaveFile.Enabled")));
			this.miSaveFile.Index = 2;
			this.miSaveFile.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSaveFile.Shortcut")));
			this.miSaveFile.ShowShortcut = ((bool)(resources.GetObject("miSaveFile.ShowShortcut")));
			this.miSaveFile.Text = resources.GetString("miSaveFile.Text");
			this.miSaveFile.Visible = ((bool)(resources.GetObject("miSaveFile.Visible")));
			this.miSaveFile.Click += new System.EventHandler(this.miSaveFile_Click);
			// 
			// miSaveAsDXF
			// 
			this.miSaveAsDXF.Enabled = ((bool)(resources.GetObject("miSaveAsDXF.Enabled")));
			this.miSaveAsDXF.Index = 3;
			this.miSaveAsDXF.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSaveAsDXF.Shortcut")));
			this.miSaveAsDXF.ShowShortcut = ((bool)(resources.GetObject("miSaveAsDXF.ShowShortcut")));
			this.miSaveAsDXF.Text = resources.GetString("miSaveAsDXF.Text");
			this.miSaveAsDXF.Visible = ((bool)(resources.GetObject("miSaveAsDXF.Visible")));
			this.miSaveAsDXF.Click += new System.EventHandler(this.miSaveAsDXF_Click);
			// 
			// miPrint
			// 
			this.miPrint.Enabled = ((bool)(resources.GetObject("miPrint.Enabled")));
			this.miPrint.Index = 4;
			this.miPrint.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miPrint.Shortcut")));
			this.miPrint.ShowShortcut = ((bool)(resources.GetObject("miPrint.ShowShortcut")));
			this.miPrint.Text = resources.GetString("miPrint.Text");
			this.miPrint.Visible = ((bool)(resources.GetObject("miPrint.Visible")));
			this.miPrint.Click += new System.EventHandler(this.miPrint_Click);
			// 
			// miCustomPrint
			// 
			this.miCustomPrint.Enabled = ((bool)(resources.GetObject("miCustomPrint.Enabled")));
			this.miCustomPrint.Index = 5;
			this.miCustomPrint.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miCustomPrint.Shortcut")));
			this.miCustomPrint.ShowShortcut = ((bool)(resources.GetObject("miCustomPrint.ShowShortcut")));
			this.miCustomPrint.Text = resources.GetString("miCustomPrint.Text");
			this.miCustomPrint.Visible = ((bool)(resources.GetObject("miCustomPrint.Visible")));
			this.miCustomPrint.Click += new System.EventHandler(this.miCustomPrint_Click);
			// 
			// miPrintPreview
			// 
			this.miPrintPreview.Enabled = ((bool)(resources.GetObject("miPrintPreview.Enabled")));
			this.miPrintPreview.Index = 6;
			this.miPrintPreview.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miPrintPreview.Shortcut")));
			this.miPrintPreview.ShowShortcut = ((bool)(resources.GetObject("miPrintPreview.ShowShortcut")));
			this.miPrintPreview.Text = resources.GetString("miPrintPreview.Text");
			this.miPrintPreview.Visible = ((bool)(resources.GetObject("miPrintPreview.Visible")));
			this.miPrintPreview.Click += new System.EventHandler(this.miPrintPreview_Click);
			// 
			// miClosePicture
			// 
			this.miClosePicture.Enabled = ((bool)(resources.GetObject("miClosePicture.Enabled")));
			this.miClosePicture.Index = 7;
			this.miClosePicture.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miClosePicture.Shortcut")));
			this.miClosePicture.ShowShortcut = ((bool)(resources.GetObject("miClosePicture.ShowShortcut")));
			this.miClosePicture.Text = resources.GetString("miClosePicture.Text");
			this.miClosePicture.Visible = ((bool)(resources.GetObject("miClosePicture.Visible")));
			this.miClosePicture.Click += new System.EventHandler(this.miClosePicture_Click);
			// 
			// miSeparator1
			// 
			this.miSeparator1.Enabled = ((bool)(resources.GetObject("miSeparator1.Enabled")));
			this.miSeparator1.Index = 8;
			this.miSeparator1.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSeparator1.Shortcut")));
			this.miSeparator1.ShowShortcut = ((bool)(resources.GetObject("miSeparator1.ShowShortcut")));
			this.miSeparator1.Text = resources.GetString("miSeparator1.Text");
			this.miSeparator1.Visible = ((bool)(resources.GetObject("miSeparator1.Visible")));
			// 
			// miExit
			// 
			this.miExit.Enabled = ((bool)(resources.GetObject("miExit.Enabled")));
			this.miExit.Index = 9;
			this.miExit.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miExit.Shortcut")));
			this.miExit.ShowShortcut = ((bool)(resources.GetObject("miExit.ShowShortcut")));
			this.miExit.Text = resources.GetString("miExit.Text");
			this.miExit.Visible = ((bool)(resources.GetObject("miExit.Visible")));
			this.miExit.Click += new System.EventHandler(this.miExit_Click);
			// 
			// editMenuItem
			// 
			this.editMenuItem.Enabled = ((bool)(resources.GetObject("editMenuItem.Enabled")));
			this.editMenuItem.Index = 1;
			this.editMenuItem.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																						 this.miCopyAsBMP});
			this.editMenuItem.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("editMenuItem.Shortcut")));
			this.editMenuItem.ShowShortcut = ((bool)(resources.GetObject("editMenuItem.ShowShortcut")));
			this.editMenuItem.Text = resources.GetString("editMenuItem.Text");
			this.editMenuItem.Visible = ((bool)(resources.GetObject("editMenuItem.Visible")));
			// 
			// miCopyAsBMP
			// 
			this.miCopyAsBMP.Enabled = ((bool)(resources.GetObject("miCopyAsBMP.Enabled")));
			this.miCopyAsBMP.Index = 0;
			this.miCopyAsBMP.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miCopyAsBMP.Shortcut")));
			this.miCopyAsBMP.ShowShortcut = ((bool)(resources.GetObject("miCopyAsBMP.ShowShortcut")));
			this.miCopyAsBMP.Text = resources.GetString("miCopyAsBMP.Text");
			this.miCopyAsBMP.Visible = ((bool)(resources.GetObject("miCopyAsBMP.Visible")));
			this.miCopyAsBMP.Click += new System.EventHandler(this.miCopyAsBMP_Click);
			// 
			// mView
			// 
			this.mView.Enabled = ((bool)(resources.GetObject("mView.Enabled")));
			this.mView.Index = 2;
			this.mView.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																				  this.miShowEntityTree,
																				  this.miSeparator2,
																				  this.miZoomIn,
																				  this.miZoomOut,
																				  this.miScale,
																				  this.miFitToWindow,
																				  this.miSeparator3,
																				  this.miShowShxForm,
																				  this.miShowOptionsForm});
			this.mView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("mView.Shortcut")));
			this.mView.ShowShortcut = ((bool)(resources.GetObject("mView.ShowShortcut")));
			this.mView.Text = resources.GetString("mView.Text");
			this.mView.Visible = ((bool)(resources.GetObject("mView.Visible")));
			// 
			// miShowEntityTree
			// 
			this.miShowEntityTree.Checked = true;
			this.miShowEntityTree.Enabled = ((bool)(resources.GetObject("miShowEntityTree.Enabled")));
			this.miShowEntityTree.Index = 0;
			this.miShowEntityTree.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miShowEntityTree.Shortcut")));
			this.miShowEntityTree.ShowShortcut = ((bool)(resources.GetObject("miShowEntityTree.ShowShortcut")));
			this.miShowEntityTree.Text = resources.GetString("miShowEntityTree.Text");
			this.miShowEntityTree.Visible = ((bool)(resources.GetObject("miShowEntityTree.Visible")));
			this.miShowEntityTree.Click += new System.EventHandler(this.miShowEntityTree_Click);
			// 
			// miSeparator2
			// 
			this.miSeparator2.Enabled = ((bool)(resources.GetObject("miSeparator2.Enabled")));
			this.miSeparator2.Index = 1;
			this.miSeparator2.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSeparator2.Shortcut")));
			this.miSeparator2.ShowShortcut = ((bool)(resources.GetObject("miSeparator2.ShowShortcut")));
			this.miSeparator2.Text = resources.GetString("miSeparator2.Text");
			this.miSeparator2.Visible = ((bool)(resources.GetObject("miSeparator2.Visible")));
			// 
			// miZoomIn
			// 
			this.miZoomIn.Enabled = ((bool)(resources.GetObject("miZoomIn.Enabled")));
			this.miZoomIn.Index = 2;
			this.miZoomIn.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miZoomIn.Shortcut")));
			this.miZoomIn.ShowShortcut = ((bool)(resources.GetObject("miZoomIn.ShowShortcut")));
			this.miZoomIn.Text = resources.GetString("miZoomIn.Text");
			this.miZoomIn.Visible = ((bool)(resources.GetObject("miZoomIn.Visible")));
			this.miZoomIn.Click += new System.EventHandler(this.miZoomIn_Click);
			// 
			// miZoomOut
			// 
			this.miZoomOut.Enabled = ((bool)(resources.GetObject("miZoomOut.Enabled")));
			this.miZoomOut.Index = 3;
			this.miZoomOut.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miZoomOut.Shortcut")));
			this.miZoomOut.ShowShortcut = ((bool)(resources.GetObject("miZoomOut.ShowShortcut")));
			this.miZoomOut.Text = resources.GetString("miZoomOut.Text");
			this.miZoomOut.Visible = ((bool)(resources.GetObject("miZoomOut.Visible")));
			this.miZoomOut.Click += new System.EventHandler(this.miZoomOut_Click);
			// 
			// miScale
			// 
			this.miScale.Enabled = ((bool)(resources.GetObject("miScale.Enabled")));
			this.miScale.Index = 4;
			this.miScale.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					this.miZoom10,
																					this.miZoom25,
																					this.miZoom50,
																					this.miZoom100,
																					this.miZoom200,
																					this.miZoom400,
																					this.miZoom800});
			this.miScale.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miScale.Shortcut")));
			this.miScale.ShowShortcut = ((bool)(resources.GetObject("miScale.ShowShortcut")));
			this.miScale.Text = resources.GetString("miScale.Text");
			this.miScale.Visible = ((bool)(resources.GetObject("miScale.Visible")));
			// 
			// miZoom10
			// 
			this.miZoom10.Enabled = ((bool)(resources.GetObject("miZoom10.Enabled")));
			this.miZoom10.Index = 0;
			this.miZoom10.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miZoom10.Shortcut")));
			this.miZoom10.ShowShortcut = ((bool)(resources.GetObject("miZoom10.ShowShortcut")));
			this.miZoom10.Text = resources.GetString("miZoom10.Text");
			this.miZoom10.Visible = ((bool)(resources.GetObject("miZoom10.Visible")));
			this.miZoom10.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom25
			// 
			this.miZoom25.Enabled = ((bool)(resources.GetObject("miZoom25.Enabled")));
			this.miZoom25.Index = 1;
			this.miZoom25.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miZoom25.Shortcut")));
			this.miZoom25.ShowShortcut = ((bool)(resources.GetObject("miZoom25.ShowShortcut")));
			this.miZoom25.Text = resources.GetString("miZoom25.Text");
			this.miZoom25.Visible = ((bool)(resources.GetObject("miZoom25.Visible")));
			this.miZoom25.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom50
			// 
			this.miZoom50.Enabled = ((bool)(resources.GetObject("miZoom50.Enabled")));
			this.miZoom50.Index = 2;
			this.miZoom50.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miZoom50.Shortcut")));
			this.miZoom50.ShowShortcut = ((bool)(resources.GetObject("miZoom50.ShowShortcut")));
			this.miZoom50.Text = resources.GetString("miZoom50.Text");
			this.miZoom50.Visible = ((bool)(resources.GetObject("miZoom50.Visible")));
			this.miZoom50.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom100
			// 
			this.miZoom100.Enabled = ((bool)(resources.GetObject("miZoom100.Enabled")));
			this.miZoom100.Index = 3;
			this.miZoom100.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miZoom100.Shortcut")));
			this.miZoom100.ShowShortcut = ((bool)(resources.GetObject("miZoom100.ShowShortcut")));
			this.miZoom100.Text = resources.GetString("miZoom100.Text");
			this.miZoom100.Visible = ((bool)(resources.GetObject("miZoom100.Visible")));
			this.miZoom100.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom200
			// 
			this.miZoom200.Enabled = ((bool)(resources.GetObject("miZoom200.Enabled")));
			this.miZoom200.Index = 4;
			this.miZoom200.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miZoom200.Shortcut")));
			this.miZoom200.ShowShortcut = ((bool)(resources.GetObject("miZoom200.ShowShortcut")));
			this.miZoom200.Text = resources.GetString("miZoom200.Text");
			this.miZoom200.Visible = ((bool)(resources.GetObject("miZoom200.Visible")));
			this.miZoom200.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom400
			// 
			this.miZoom400.Enabled = ((bool)(resources.GetObject("miZoom400.Enabled")));
			this.miZoom400.Index = 5;
			this.miZoom400.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miZoom400.Shortcut")));
			this.miZoom400.ShowShortcut = ((bool)(resources.GetObject("miZoom400.ShowShortcut")));
			this.miZoom400.Text = resources.GetString("miZoom400.Text");
			this.miZoom400.Visible = ((bool)(resources.GetObject("miZoom400.Visible")));
			this.miZoom400.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miZoom800
			// 
			this.miZoom800.Enabled = ((bool)(resources.GetObject("miZoom800.Enabled")));
			this.miZoom800.Index = 6;
			this.miZoom800.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miZoom800.Shortcut")));
			this.miZoom800.ShowShortcut = ((bool)(resources.GetObject("miZoom800.ShowShortcut")));
			this.miZoom800.Text = resources.GetString("miZoom800.Text");
			this.miZoom800.Visible = ((bool)(resources.GetObject("miZoom800.Visible")));
			this.miZoom800.Click += new System.EventHandler(this.miZoom_Click);
			// 
			// miFitToWindow
			// 
			this.miFitToWindow.Enabled = ((bool)(resources.GetObject("miFitToWindow.Enabled")));
			this.miFitToWindow.Index = 5;
			this.miFitToWindow.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miFitToWindow.Shortcut")));
			this.miFitToWindow.ShowShortcut = ((bool)(resources.GetObject("miFitToWindow.ShowShortcut")));
			this.miFitToWindow.Text = resources.GetString("miFitToWindow.Text");
			this.miFitToWindow.Visible = ((bool)(resources.GetObject("miFitToWindow.Visible")));
			this.miFitToWindow.Click += new System.EventHandler(this.miFitToWindow_Click);
			// 
			// miSeparator3
			// 
			this.miSeparator3.Enabled = ((bool)(resources.GetObject("miSeparator3.Enabled")));
			this.miSeparator3.Index = 6;
			this.miSeparator3.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSeparator3.Shortcut")));
			this.miSeparator3.ShowShortcut = ((bool)(resources.GetObject("miSeparator3.ShowShortcut")));
			this.miSeparator3.Text = resources.GetString("miSeparator3.Text");
			this.miSeparator3.Visible = ((bool)(resources.GetObject("miSeparator3.Visible")));
			// 
			// miShowShxForm
			// 
			this.miShowShxForm.Enabled = ((bool)(resources.GetObject("miShowShxForm.Enabled")));
			this.miShowShxForm.Index = 7;
			this.miShowShxForm.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miShowShxForm.Shortcut")));
			this.miShowShxForm.ShowShortcut = ((bool)(resources.GetObject("miShowShxForm.ShowShortcut")));
			this.miShowShxForm.Text = resources.GetString("miShowShxForm.Text");
			this.miShowShxForm.Visible = ((bool)(resources.GetObject("miShowShxForm.Visible")));
			this.miShowShxForm.Click += new System.EventHandler(this.miShowShxForm_Click);
			// 
			// miShowOptionsForm
			// 
			this.miShowOptionsForm.Enabled = ((bool)(resources.GetObject("miShowOptionsForm.Enabled")));
			this.miShowOptionsForm.Index = 8;
			this.miShowOptionsForm.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miShowOptionsForm.Shortcut")));
			this.miShowOptionsForm.ShowShortcut = ((bool)(resources.GetObject("miShowOptionsForm.ShowShortcut")));
			this.miShowOptionsForm.Text = resources.GetString("miShowOptionsForm.Text");
			this.miShowOptionsForm.Visible = ((bool)(resources.GetObject("miShowOptionsForm.Visible")));
			this.miShowOptionsForm.Click += new System.EventHandler(this.miShowOptionsForm_Click);
			// 
			// cADFilesMenuItem
			// 
			this.cADFilesMenuItem.Enabled = ((bool)(resources.GetObject("cADFilesMenuItem.Enabled")));
			this.cADFilesMenuItem.Index = 3;
			this.cADFilesMenuItem.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																							 this.miDrawNormalColor,
																							 this.miDrawBlackColor,
																							 this.miWhiteBackground,
																							 this.miBlackBackground,
																							 this.miChangeBackgroundColor,
																							 this.miSeparator4,
																							 this.miShowLineWeight,
																							 this.miArcsSplit,
																							 this.miDimShow,
																							 this.miTextsShow,
																							 this.miSeparator5,
																							 this.miLayersShow,
																							 this.mi3DViews,
																							 this.miEnable3DOrbit});
			this.cADFilesMenuItem.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("cADFilesMenuItem.Shortcut")));
			this.cADFilesMenuItem.ShowShortcut = ((bool)(resources.GetObject("cADFilesMenuItem.ShowShortcut")));
			this.cADFilesMenuItem.Text = resources.GetString("cADFilesMenuItem.Text");
			this.cADFilesMenuItem.Visible = ((bool)(resources.GetObject("cADFilesMenuItem.Visible")));
			// 
			// miDrawNormalColor
			// 
			this.miDrawNormalColor.Checked = true;
			this.miDrawNormalColor.Enabled = ((bool)(resources.GetObject("miDrawNormalColor.Enabled")));
			this.miDrawNormalColor.Index = 0;
			this.miDrawNormalColor.RadioCheck = true;
			this.miDrawNormalColor.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miDrawNormalColor.Shortcut")));
			this.miDrawNormalColor.ShowShortcut = ((bool)(resources.GetObject("miDrawNormalColor.ShowShortcut")));
			this.miDrawNormalColor.Text = resources.GetString("miDrawNormalColor.Text");
			this.miDrawNormalColor.Visible = ((bool)(resources.GetObject("miDrawNormalColor.Visible")));
			this.miDrawNormalColor.Click += new System.EventHandler(this.miDrawNormalColor_Click);
			// 
			// miDrawBlackColor
			// 
			this.miDrawBlackColor.Enabled = ((bool)(resources.GetObject("miDrawBlackColor.Enabled")));
			this.miDrawBlackColor.Index = 1;
			this.miDrawBlackColor.RadioCheck = true;
			this.miDrawBlackColor.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miDrawBlackColor.Shortcut")));
			this.miDrawBlackColor.ShowShortcut = ((bool)(resources.GetObject("miDrawBlackColor.ShowShortcut")));
			this.miDrawBlackColor.Text = resources.GetString("miDrawBlackColor.Text");
			this.miDrawBlackColor.Visible = ((bool)(resources.GetObject("miDrawBlackColor.Visible")));
			this.miDrawBlackColor.Click += new System.EventHandler(this.miDrawBlackColor_Click);
			// 
			// miWhiteBackground
			// 
			this.miWhiteBackground.Enabled = ((bool)(resources.GetObject("miWhiteBackground.Enabled")));
			this.miWhiteBackground.Index = 2;
			this.miWhiteBackground.RadioCheck = true;
			this.miWhiteBackground.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miWhiteBackground.Shortcut")));
			this.miWhiteBackground.ShowShortcut = ((bool)(resources.GetObject("miWhiteBackground.ShowShortcut")));
			this.miWhiteBackground.Text = resources.GetString("miWhiteBackground.Text");
			this.miWhiteBackground.Visible = ((bool)(resources.GetObject("miWhiteBackground.Visible")));
			this.miWhiteBackground.Click += new System.EventHandler(this.miWhiteBackground_Click);
			// 
			// miBlackBackground
			// 
			this.miBlackBackground.Enabled = ((bool)(resources.GetObject("miBlackBackground.Enabled")));
			this.miBlackBackground.Index = 3;
			this.miBlackBackground.RadioCheck = true;
			this.miBlackBackground.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miBlackBackground.Shortcut")));
			this.miBlackBackground.ShowShortcut = ((bool)(resources.GetObject("miBlackBackground.ShowShortcut")));
			this.miBlackBackground.Text = resources.GetString("miBlackBackground.Text");
			this.miBlackBackground.Visible = ((bool)(resources.GetObject("miBlackBackground.Visible")));
			this.miBlackBackground.Click += new System.EventHandler(this.miBlackBackground_Click);
			// 
			// miChangeBackgroundColor
			// 
			this.miChangeBackgroundColor.Enabled = ((bool)(resources.GetObject("miChangeBackgroundColor.Enabled")));
			this.miChangeBackgroundColor.Index = 4;
			this.miChangeBackgroundColor.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miChangeBackgroundColor.Shortcut")));
			this.miChangeBackgroundColor.ShowShortcut = ((bool)(resources.GetObject("miChangeBackgroundColor.ShowShortcut")));
			this.miChangeBackgroundColor.Text = resources.GetString("miChangeBackgroundColor.Text");
			this.miChangeBackgroundColor.Visible = ((bool)(resources.GetObject("miChangeBackgroundColor.Visible")));
			this.miChangeBackgroundColor.Click += new System.EventHandler(this.miChangeBackgroundColor_Click);
			// 
			// miSeparator4
			// 
			this.miSeparator4.Enabled = ((bool)(resources.GetObject("miSeparator4.Enabled")));
			this.miSeparator4.Index = 5;
			this.miSeparator4.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSeparator4.Shortcut")));
			this.miSeparator4.ShowShortcut = ((bool)(resources.GetObject("miSeparator4.ShowShortcut")));
			this.miSeparator4.Text = resources.GetString("miSeparator4.Text");
			this.miSeparator4.Visible = ((bool)(resources.GetObject("miSeparator4.Visible")));
			// 
			// miShowLineWeight
			// 
			this.miShowLineWeight.Checked = true;
			this.miShowLineWeight.Enabled = ((bool)(resources.GetObject("miShowLineWeight.Enabled")));
			this.miShowLineWeight.Index = 6;
			this.miShowLineWeight.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miShowLineWeight.Shortcut")));
			this.miShowLineWeight.ShowShortcut = ((bool)(resources.GetObject("miShowLineWeight.ShowShortcut")));
			this.miShowLineWeight.Text = resources.GetString("miShowLineWeight.Text");
			this.miShowLineWeight.Visible = ((bool)(resources.GetObject("miShowLineWeight.Visible")));
			this.miShowLineWeight.Click += new System.EventHandler(this.miShowLineWeight_Click);
			// 
			// miArcsSplit
			// 
			this.miArcsSplit.Checked = true;
			this.miArcsSplit.Enabled = ((bool)(resources.GetObject("miArcsSplit.Enabled")));
			this.miArcsSplit.Index = 7;
			this.miArcsSplit.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miArcsSplit.Shortcut")));
			this.miArcsSplit.ShowShortcut = ((bool)(resources.GetObject("miArcsSplit.ShowShortcut")));
			this.miArcsSplit.Text = resources.GetString("miArcsSplit.Text");
			this.miArcsSplit.Visible = ((bool)(resources.GetObject("miArcsSplit.Visible")));
			this.miArcsSplit.Click += new System.EventHandler(this.miArcsSplit_Click);
			// 
			// miDimShow
			// 
			this.miDimShow.Checked = true;
			this.miDimShow.Enabled = ((bool)(resources.GetObject("miDimShow.Enabled")));
			this.miDimShow.Index = 8;
			this.miDimShow.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miDimShow.Shortcut")));
			this.miDimShow.ShowShortcut = ((bool)(resources.GetObject("miDimShow.ShowShortcut")));
			this.miDimShow.Text = resources.GetString("miDimShow.Text");
			this.miDimShow.Visible = ((bool)(resources.GetObject("miDimShow.Visible")));
			this.miDimShow.Click += new System.EventHandler(this.miDimShow_Click);
			// 
			// miTextsShow
			// 
			this.miTextsShow.Checked = true;
			this.miTextsShow.Enabled = ((bool)(resources.GetObject("miTextsShow.Enabled")));
			this.miTextsShow.Index = 9;
			this.miTextsShow.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miTextsShow.Shortcut")));
			this.miTextsShow.ShowShortcut = ((bool)(resources.GetObject("miTextsShow.ShowShortcut")));
			this.miTextsShow.Text = resources.GetString("miTextsShow.Text");
			this.miTextsShow.Visible = ((bool)(resources.GetObject("miTextsShow.Visible")));
			this.miTextsShow.Click += new System.EventHandler(this.miTextsShow_Click);
			// 
			// miSeparator5
			// 
			this.miSeparator5.Enabled = ((bool)(resources.GetObject("miSeparator5.Enabled")));
			this.miSeparator5.Index = 10;
			this.miSeparator5.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSeparator5.Shortcut")));
			this.miSeparator5.ShowShortcut = ((bool)(resources.GetObject("miSeparator5.ShowShortcut")));
			this.miSeparator5.Text = resources.GetString("miSeparator5.Text");
			this.miSeparator5.Visible = ((bool)(resources.GetObject("miSeparator5.Visible")));
			// 
			// miLayersShow
			// 
			this.miLayersShow.Enabled = ((bool)(resources.GetObject("miLayersShow.Enabled")));
			this.miLayersShow.Index = 11;
			this.miLayersShow.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miLayersShow.Shortcut")));
			this.miLayersShow.ShowShortcut = ((bool)(resources.GetObject("miLayersShow.ShowShortcut")));
			this.miLayersShow.Text = resources.GetString("miLayersShow.Text");
			this.miLayersShow.Visible = ((bool)(resources.GetObject("miLayersShow.Visible")));
			this.miLayersShow.Click += new System.EventHandler(this.miLayersShow_Click);
			// 
			// mi3DViews
			// 
			this.mi3DViews.Enabled = ((bool)(resources.GetObject("mi3DViews.Enabled")));
			this.mi3DViews.Index = 12;
			this.mi3DViews.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																					  this.miInitialView,
																					  this.miTopView,
																					  this.miBottomView,
																					  this.miLeftView,
																					  this.miRightView,
																					  this.miFrontView,
																					  this.miBackView,
																					  this.miSWIsometricView,
																					  this.miSEIsometricView,
																					  this.miNEIsometricView,
																					  this.miNWIsometricView});
			this.mi3DViews.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("mi3DViews.Shortcut")));
			this.mi3DViews.ShowShortcut = ((bool)(resources.GetObject("mi3DViews.ShowShortcut")));
			this.mi3DViews.Text = resources.GetString("mi3DViews.Text");
			this.mi3DViews.Visible = ((bool)(resources.GetObject("mi3DViews.Visible")));
			// 
			// miInitialView
			// 
			this.miInitialView.Enabled = ((bool)(resources.GetObject("miInitialView.Enabled")));
			this.miInitialView.Index = 0;
			this.miInitialView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miInitialView.Shortcut")));
			this.miInitialView.ShowShortcut = ((bool)(resources.GetObject("miInitialView.ShowShortcut")));
			this.miInitialView.Text = resources.GetString("miInitialView.Text");
			this.miInitialView.Visible = ((bool)(resources.GetObject("miInitialView.Visible")));
			this.miInitialView.Click += new System.EventHandler(this.miInitialView_Click);
			// 
			// miTopView
			// 
			this.miTopView.Enabled = ((bool)(resources.GetObject("miTopView.Enabled")));
			this.miTopView.Index = 1;
			this.miTopView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miTopView.Shortcut")));
			this.miTopView.ShowShortcut = ((bool)(resources.GetObject("miTopView.ShowShortcut")));
			this.miTopView.Text = resources.GetString("miTopView.Text");
			this.miTopView.Visible = ((bool)(resources.GetObject("miTopView.Visible")));
			this.miTopView.Click += new System.EventHandler(this.miTopView_Click);
			// 
			// miBottomView
			// 
			this.miBottomView.Enabled = ((bool)(resources.GetObject("miBottomView.Enabled")));
			this.miBottomView.Index = 2;
			this.miBottomView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miBottomView.Shortcut")));
			this.miBottomView.ShowShortcut = ((bool)(resources.GetObject("miBottomView.ShowShortcut")));
			this.miBottomView.Text = resources.GetString("miBottomView.Text");
			this.miBottomView.Visible = ((bool)(resources.GetObject("miBottomView.Visible")));
			this.miBottomView.Click += new System.EventHandler(this.miBottomView_Click);
			// 
			// miLeftView
			// 
			this.miLeftView.Enabled = ((bool)(resources.GetObject("miLeftView.Enabled")));
			this.miLeftView.Index = 3;
			this.miLeftView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miLeftView.Shortcut")));
			this.miLeftView.ShowShortcut = ((bool)(resources.GetObject("miLeftView.ShowShortcut")));
			this.miLeftView.Text = resources.GetString("miLeftView.Text");
			this.miLeftView.Visible = ((bool)(resources.GetObject("miLeftView.Visible")));
			this.miLeftView.Click += new System.EventHandler(this.miLeftView_Click);
			// 
			// miRightView
			// 
			this.miRightView.Enabled = ((bool)(resources.GetObject("miRightView.Enabled")));
			this.miRightView.Index = 4;
			this.miRightView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miRightView.Shortcut")));
			this.miRightView.ShowShortcut = ((bool)(resources.GetObject("miRightView.ShowShortcut")));
			this.miRightView.Text = resources.GetString("miRightView.Text");
			this.miRightView.Visible = ((bool)(resources.GetObject("miRightView.Visible")));
			this.miRightView.Click += new System.EventHandler(this.miRightView_Click);
			// 
			// miFrontView
			// 
			this.miFrontView.Enabled = ((bool)(resources.GetObject("miFrontView.Enabled")));
			this.miFrontView.Index = 5;
			this.miFrontView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miFrontView.Shortcut")));
			this.miFrontView.ShowShortcut = ((bool)(resources.GetObject("miFrontView.ShowShortcut")));
			this.miFrontView.Text = resources.GetString("miFrontView.Text");
			this.miFrontView.Visible = ((bool)(resources.GetObject("miFrontView.Visible")));
			this.miFrontView.Click += new System.EventHandler(this.miFrontView_Click);
			// 
			// miBackView
			// 
			this.miBackView.Enabled = ((bool)(resources.GetObject("miBackView.Enabled")));
			this.miBackView.Index = 6;
			this.miBackView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miBackView.Shortcut")));
			this.miBackView.ShowShortcut = ((bool)(resources.GetObject("miBackView.ShowShortcut")));
			this.miBackView.Text = resources.GetString("miBackView.Text");
			this.miBackView.Visible = ((bool)(resources.GetObject("miBackView.Visible")));
			this.miBackView.Click += new System.EventHandler(this.miBackView_Click);
			// 
			// miSWIsometricView
			// 
			this.miSWIsometricView.Enabled = ((bool)(resources.GetObject("miSWIsometricView.Enabled")));
			this.miSWIsometricView.Index = 7;
			this.miSWIsometricView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSWIsometricView.Shortcut")));
			this.miSWIsometricView.ShowShortcut = ((bool)(resources.GetObject("miSWIsometricView.ShowShortcut")));
			this.miSWIsometricView.Text = resources.GetString("miSWIsometricView.Text");
			this.miSWIsometricView.Visible = ((bool)(resources.GetObject("miSWIsometricView.Visible")));
			this.miSWIsometricView.Click += new System.EventHandler(this.miSWIsometricView_Click);
			// 
			// miSEIsometricView
			// 
			this.miSEIsometricView.Enabled = ((bool)(resources.GetObject("miSEIsometricView.Enabled")));
			this.miSEIsometricView.Index = 8;
			this.miSEIsometricView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSEIsometricView.Shortcut")));
			this.miSEIsometricView.ShowShortcut = ((bool)(resources.GetObject("miSEIsometricView.ShowShortcut")));
			this.miSEIsometricView.Text = resources.GetString("miSEIsometricView.Text");
			this.miSEIsometricView.Visible = ((bool)(resources.GetObject("miSEIsometricView.Visible")));
			this.miSEIsometricView.Click += new System.EventHandler(this.miSEIsometricView_Click);
			// 
			// miNEIsometricView
			// 
			this.miNEIsometricView.Enabled = ((bool)(resources.GetObject("miNEIsometricView.Enabled")));
			this.miNEIsometricView.Index = 9;
			this.miNEIsometricView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miNEIsometricView.Shortcut")));
			this.miNEIsometricView.ShowShortcut = ((bool)(resources.GetObject("miNEIsometricView.ShowShortcut")));
			this.miNEIsometricView.Text = resources.GetString("miNEIsometricView.Text");
			this.miNEIsometricView.Visible = ((bool)(resources.GetObject("miNEIsometricView.Visible")));
			this.miNEIsometricView.Click += new System.EventHandler(this.miNEIsometricView_Click);
			// 
			// miNWIsometricView
			// 
			this.miNWIsometricView.Enabled = ((bool)(resources.GetObject("miNWIsometricView.Enabled")));
			this.miNWIsometricView.Index = 10;
			this.miNWIsometricView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miNWIsometricView.Shortcut")));
			this.miNWIsometricView.ShowShortcut = ((bool)(resources.GetObject("miNWIsometricView.ShowShortcut")));
			this.miNWIsometricView.Text = resources.GetString("miNWIsometricView.Text");
			this.miNWIsometricView.Visible = ((bool)(resources.GetObject("miNWIsometricView.Visible")));
			this.miNWIsometricView.Click += new System.EventHandler(this.miNWIsometricView_Click);
			// 
			// miEnable3DOrbit
			// 
			this.miEnable3DOrbit.Enabled = ((bool)(resources.GetObject("miEnable3DOrbit.Enabled")));
			this.miEnable3DOrbit.Index = 13;
			this.miEnable3DOrbit.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miEnable3DOrbit.Shortcut")));
			this.miEnable3DOrbit.ShowShortcut = ((bool)(resources.GetObject("miEnable3DOrbit.ShowShortcut")));
			this.miEnable3DOrbit.Text = resources.GetString("miEnable3DOrbit.Text");
			this.miEnable3DOrbit.Visible = ((bool)(resources.GetObject("miEnable3DOrbit.Visible")));
			this.miEnable3DOrbit.Click += new System.EventHandler(this.miEnable3DOrbit_Click);
			// 
			// helpMenuItem
			// 
			this.helpMenuItem.Enabled = ((bool)(resources.GetObject("helpMenuItem.Enabled")));
			this.helpMenuItem.Index = 4;
			this.helpMenuItem.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																						 this.miLanguages,
																						 this.miRegistration,
																						 this.miFloatLic,
																						 this.miAbout});
			this.helpMenuItem.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("helpMenuItem.Shortcut")));
			this.helpMenuItem.ShowShortcut = ((bool)(resources.GetObject("helpMenuItem.ShowShortcut")));
			this.helpMenuItem.Text = resources.GetString("helpMenuItem.Text");
			this.helpMenuItem.Visible = ((bool)(resources.GetObject("helpMenuItem.Visible")));
			// 
			// miLanguages
			// 
			this.miLanguages.Enabled = ((bool)(resources.GetObject("miLanguages.Enabled")));
			this.miLanguages.Index = 0;
			this.miLanguages.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miLanguages.Shortcut")));
			this.miLanguages.ShowShortcut = ((bool)(resources.GetObject("miLanguages.ShowShortcut")));
			this.miLanguages.Text = resources.GetString("miLanguages.Text");
			this.miLanguages.Visible = ((bool)(resources.GetObject("miLanguages.Visible")));
			// 
			// miRegistration
			// 
			this.miRegistration.Enabled = ((bool)(resources.GetObject("miRegistration.Enabled")));
			this.miRegistration.Index = 1;
			this.miRegistration.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miRegistration.Shortcut")));
			this.miRegistration.ShowShortcut = ((bool)(resources.GetObject("miRegistration.ShowShortcut")));
			this.miRegistration.Text = resources.GetString("miRegistration.Text");
			this.miRegistration.Visible = ((bool)(resources.GetObject("miRegistration.Visible")));
			this.miRegistration.Click += new System.EventHandler(this.miRegistration_Click);
			// 
			// miFloatLic
			// 
			this.miFloatLic.Enabled = ((bool)(resources.GetObject("miFloatLic.Enabled")));
			this.miFloatLic.Index = 2;
			this.miFloatLic.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miFloatLic.Shortcut")));
			this.miFloatLic.ShowShortcut = ((bool)(resources.GetObject("miFloatLic.ShowShortcut")));
			this.miFloatLic.Text = resources.GetString("miFloatLic.Text");
			this.miFloatLic.Visible = ((bool)(resources.GetObject("miFloatLic.Visible")));
			this.miFloatLic.Click += new System.EventHandler(this.miFloatLic_Click);
			// 
			// miAbout
			// 
			this.miAbout.Enabled = ((bool)(resources.GetObject("miAbout.Enabled")));
			this.miAbout.Index = 3;
			this.miAbout.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miAbout.Shortcut")));
			this.miAbout.ShowShortcut = ((bool)(resources.GetObject("miAbout.ShowShortcut")));
			this.miAbout.Text = resources.GetString("miAbout.Text");
			this.miAbout.Visible = ((bool)(resources.GetObject("miAbout.Visible")));
			this.miAbout.Click += new System.EventHandler(this.miAbout_Click);
			// 
			// tlbTool
			// 
			this.tlbTool.AccessibleDescription = resources.GetString("tlbTool.AccessibleDescription");
			this.tlbTool.AccessibleName = resources.GetString("tlbTool.AccessibleName");
			this.tlbTool.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("tlbTool.Anchor")));
			this.tlbTool.Appearance = ((System.Windows.Forms.ToolBarAppearance)(resources.GetObject("tlbTool.Appearance")));
			this.tlbTool.AutoSize = ((bool)(resources.GetObject("tlbTool.AutoSize")));
			this.tlbTool.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("tlbTool.BackgroundImage")));
			this.tlbTool.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.tlbTool.Buttons.AddRange(new System.Windows.Forms.ToolBarButton[] {
																					   this.tlbOpen,
																					   this.tlbZoomIn,
																					   this.tlbZoomOut,
																					   this.tlbSave,
																					   this.tlbWhite,
																					   this.tlbBlack,
																					   this.tlbColor,
																					   this.tlb3d,
																					   this.tlbRotateLeft,
																					   this.tlbRotateRight,
																					   this.tlbRotateAngle,
																					   this.tlbLay,
																					   this.tlbArcPoly,
																					   this.tlbBlackMode,
																					   this.tlbColorMode,
																					   this.tlbDefSize,
																					   this.tlbTextShow,
																					   this.tlbDimShow,
																					   this.tlbSaveImageClip,
																					   this.tlbPrint,
																					   this.tlbSHX,
																					   this.tlbRect,
																					   this.tlbSelObject,
																					   this.tlbAxes,
																					   this.tlbOpenFromClipboard,
																					   this.tlbUseDoubleBuffering});
			this.tlbTool.ButtonSize = ((System.Drawing.Size)(resources.GetObject("tlbTool.ButtonSize")));
			this.tlbTool.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("tlbTool.Dock")));
			this.tlbTool.DropDownArrows = ((bool)(resources.GetObject("tlbTool.DropDownArrows")));
			this.tlbTool.Enabled = ((bool)(resources.GetObject("tlbTool.Enabled")));
			this.tlbTool.Font = ((System.Drawing.Font)(resources.GetObject("tlbTool.Font")));
			this.tlbTool.ImageList = this.imgLstToolBtn;
			this.tlbTool.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("tlbTool.ImeMode")));
			this.tlbTool.Location = ((System.Drawing.Point)(resources.GetObject("tlbTool.Location")));
			this.tlbTool.Name = "tlbTool";
			this.tlbTool.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("tlbTool.RightToLeft")));
			this.tlbTool.ShowToolTips = ((bool)(resources.GetObject("tlbTool.ShowToolTips")));
			this.tlbTool.Size = ((System.Drawing.Size)(resources.GetObject("tlbTool.Size")));
			this.tlbTool.TabIndex = ((int)(resources.GetObject("tlbTool.TabIndex")));
			this.tlbTool.TextAlign = ((System.Windows.Forms.ToolBarTextAlign)(resources.GetObject("tlbTool.TextAlign")));
			this.tlbTool.Visible = ((bool)(resources.GetObject("tlbTool.Visible")));
			this.tlbTool.Wrappable = ((bool)(resources.GetObject("tlbTool.Wrappable")));
			this.tlbTool.ButtonClick += new System.Windows.Forms.ToolBarButtonClickEventHandler(this.tlbTool_ButtonClick);
			this.tlbTool.KeyDown += new System.Windows.Forms.KeyEventHandler(this.CADPictBoxKeyDown);
			// 
			// tlbOpen
			// 
			this.tlbOpen.Enabled = ((bool)(resources.GetObject("tlbOpen.Enabled")));
			this.tlbOpen.ImageIndex = ((int)(resources.GetObject("tlbOpen.ImageIndex")));
			this.tlbOpen.Text = resources.GetString("tlbOpen.Text");
			this.tlbOpen.ToolTipText = resources.GetString("tlbOpen.ToolTipText");
			this.tlbOpen.Visible = ((bool)(resources.GetObject("tlbOpen.Visible")));
			// 
			// tlbZoomIn
			// 
			this.tlbZoomIn.Enabled = ((bool)(resources.GetObject("tlbZoomIn.Enabled")));
			this.tlbZoomIn.ImageIndex = ((int)(resources.GetObject("tlbZoomIn.ImageIndex")));
			this.tlbZoomIn.Text = resources.GetString("tlbZoomIn.Text");
			this.tlbZoomIn.ToolTipText = resources.GetString("tlbZoomIn.ToolTipText");
			this.tlbZoomIn.Visible = ((bool)(resources.GetObject("tlbZoomIn.Visible")));
			// 
			// tlbZoomOut
			// 
			this.tlbZoomOut.Enabled = ((bool)(resources.GetObject("tlbZoomOut.Enabled")));
			this.tlbZoomOut.ImageIndex = ((int)(resources.GetObject("tlbZoomOut.ImageIndex")));
			this.tlbZoomOut.Text = resources.GetString("tlbZoomOut.Text");
			this.tlbZoomOut.ToolTipText = resources.GetString("tlbZoomOut.ToolTipText");
			this.tlbZoomOut.Visible = ((bool)(resources.GetObject("tlbZoomOut.Visible")));
			// 
			// tlbSave
			// 
			this.tlbSave.Enabled = ((bool)(resources.GetObject("tlbSave.Enabled")));
			this.tlbSave.ImageIndex = ((int)(resources.GetObject("tlbSave.ImageIndex")));
			this.tlbSave.Text = resources.GetString("tlbSave.Text");
			this.tlbSave.ToolTipText = resources.GetString("tlbSave.ToolTipText");
			this.tlbSave.Visible = ((bool)(resources.GetObject("tlbSave.Visible")));
			// 
			// tlbWhite
			// 
			this.tlbWhite.Enabled = ((bool)(resources.GetObject("tlbWhite.Enabled")));
			this.tlbWhite.ImageIndex = ((int)(resources.GetObject("tlbWhite.ImageIndex")));
			this.tlbWhite.Text = resources.GetString("tlbWhite.Text");
			this.tlbWhite.ToolTipText = resources.GetString("tlbWhite.ToolTipText");
			this.tlbWhite.Visible = ((bool)(resources.GetObject("tlbWhite.Visible")));
			// 
			// tlbBlack
			// 
			this.tlbBlack.Enabled = ((bool)(resources.GetObject("tlbBlack.Enabled")));
			this.tlbBlack.ImageIndex = ((int)(resources.GetObject("tlbBlack.ImageIndex")));
			this.tlbBlack.Text = resources.GetString("tlbBlack.Text");
			this.tlbBlack.ToolTipText = resources.GetString("tlbBlack.ToolTipText");
			this.tlbBlack.Visible = ((bool)(resources.GetObject("tlbBlack.Visible")));
			// 
			// tlbColor
			// 
			this.tlbColor.Enabled = ((bool)(resources.GetObject("tlbColor.Enabled")));
			this.tlbColor.ImageIndex = ((int)(resources.GetObject("tlbColor.ImageIndex")));
			this.tlbColor.Text = resources.GetString("tlbColor.Text");
			this.tlbColor.ToolTipText = resources.GetString("tlbColor.ToolTipText");
			this.tlbColor.Visible = ((bool)(resources.GetObject("tlbColor.Visible")));
			// 
			// tlb3d
			// 
			this.tlb3d.DropDownMenu = this.menuOrbitView;
			this.tlb3d.Enabled = ((bool)(resources.GetObject("tlb3d.Enabled")));
			this.tlb3d.ImageIndex = ((int)(resources.GetObject("tlb3d.ImageIndex")));
			this.tlb3d.Style = System.Windows.Forms.ToolBarButtonStyle.DropDownButton;
			this.tlb3d.Text = resources.GetString("tlb3d.Text");
			this.tlb3d.ToolTipText = resources.GetString("tlb3d.ToolTipText");
			this.tlb3d.Visible = ((bool)(resources.GetObject("tlb3d.Visible")));
			// 
			// menuOrbitView
			// 
			this.menuOrbitView.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																						  this.miInitialOrbitView,
																						  this.miTopOrbitView,
																						  this.miBottomOrbitView,
																						  this.miLeftOrbitView,
																						  this.miRightOrbitView,
																						  this.miFrontOrbitView,
																						  this.miBackOrbitView,
																						  this.miSWOrbitView,
																						  this.miSEOrbitView,
																						  this.miNEOrbitView,
																						  this.miNWOrbitView});
			this.menuOrbitView.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("menuOrbitView.RightToLeft")));
			// 
			// miInitialOrbitView
			// 
			this.miInitialOrbitView.Enabled = ((bool)(resources.GetObject("miInitialOrbitView.Enabled")));
			this.miInitialOrbitView.Index = 0;
			this.miInitialOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miInitialOrbitView.Shortcut")));
			this.miInitialOrbitView.ShowShortcut = ((bool)(resources.GetObject("miInitialOrbitView.ShowShortcut")));
			this.miInitialOrbitView.Text = resources.GetString("miInitialOrbitView.Text");
			this.miInitialOrbitView.Visible = ((bool)(resources.GetObject("miInitialOrbitView.Visible")));
			this.miInitialOrbitView.Click += new System.EventHandler(this.miInitialView_Click);
			// 
			// miTopOrbitView
			// 
			this.miTopOrbitView.Enabled = ((bool)(resources.GetObject("miTopOrbitView.Enabled")));
			this.miTopOrbitView.Index = 1;
			this.miTopOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miTopOrbitView.Shortcut")));
			this.miTopOrbitView.ShowShortcut = ((bool)(resources.GetObject("miTopOrbitView.ShowShortcut")));
			this.miTopOrbitView.Text = resources.GetString("miTopOrbitView.Text");
			this.miTopOrbitView.Visible = ((bool)(resources.GetObject("miTopOrbitView.Visible")));
			this.miTopOrbitView.Click += new System.EventHandler(this.miTopView_Click);
			// 
			// miBottomOrbitView
			// 
			this.miBottomOrbitView.Enabled = ((bool)(resources.GetObject("miBottomOrbitView.Enabled")));
			this.miBottomOrbitView.Index = 2;
			this.miBottomOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miBottomOrbitView.Shortcut")));
			this.miBottomOrbitView.ShowShortcut = ((bool)(resources.GetObject("miBottomOrbitView.ShowShortcut")));
			this.miBottomOrbitView.Text = resources.GetString("miBottomOrbitView.Text");
			this.miBottomOrbitView.Visible = ((bool)(resources.GetObject("miBottomOrbitView.Visible")));
			this.miBottomOrbitView.Click += new System.EventHandler(this.miTopView_Click);
			// 
			// miLeftOrbitView
			// 
			this.miLeftOrbitView.Enabled = ((bool)(resources.GetObject("miLeftOrbitView.Enabled")));
			this.miLeftOrbitView.Index = 3;
			this.miLeftOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miLeftOrbitView.Shortcut")));
			this.miLeftOrbitView.ShowShortcut = ((bool)(resources.GetObject("miLeftOrbitView.ShowShortcut")));
			this.miLeftOrbitView.Text = resources.GetString("miLeftOrbitView.Text");
			this.miLeftOrbitView.Visible = ((bool)(resources.GetObject("miLeftOrbitView.Visible")));
			this.miLeftOrbitView.Click += new System.EventHandler(this.miLeftView_Click);
			// 
			// miRightOrbitView
			// 
			this.miRightOrbitView.Enabled = ((bool)(resources.GetObject("miRightOrbitView.Enabled")));
			this.miRightOrbitView.Index = 4;
			this.miRightOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miRightOrbitView.Shortcut")));
			this.miRightOrbitView.ShowShortcut = ((bool)(resources.GetObject("miRightOrbitView.ShowShortcut")));
			this.miRightOrbitView.Text = resources.GetString("miRightOrbitView.Text");
			this.miRightOrbitView.Visible = ((bool)(resources.GetObject("miRightOrbitView.Visible")));
			this.miRightOrbitView.Click += new System.EventHandler(this.miRightView_Click);
			// 
			// miFrontOrbitView
			// 
			this.miFrontOrbitView.Enabled = ((bool)(resources.GetObject("miFrontOrbitView.Enabled")));
			this.miFrontOrbitView.Index = 5;
			this.miFrontOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miFrontOrbitView.Shortcut")));
			this.miFrontOrbitView.ShowShortcut = ((bool)(resources.GetObject("miFrontOrbitView.ShowShortcut")));
			this.miFrontOrbitView.Text = resources.GetString("miFrontOrbitView.Text");
			this.miFrontOrbitView.Visible = ((bool)(resources.GetObject("miFrontOrbitView.Visible")));
			this.miFrontOrbitView.Click += new System.EventHandler(this.miFrontView_Click);
			// 
			// miBackOrbitView
			// 
			this.miBackOrbitView.Enabled = ((bool)(resources.GetObject("miBackOrbitView.Enabled")));
			this.miBackOrbitView.Index = 6;
			this.miBackOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miBackOrbitView.Shortcut")));
			this.miBackOrbitView.ShowShortcut = ((bool)(resources.GetObject("miBackOrbitView.ShowShortcut")));
			this.miBackOrbitView.Text = resources.GetString("miBackOrbitView.Text");
			this.miBackOrbitView.Visible = ((bool)(resources.GetObject("miBackOrbitView.Visible")));
			this.miBackOrbitView.Click += new System.EventHandler(this.miBackView_Click);
			// 
			// miSWOrbitView
			// 
			this.miSWOrbitView.Enabled = ((bool)(resources.GetObject("miSWOrbitView.Enabled")));
			this.miSWOrbitView.Index = 7;
			this.miSWOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSWOrbitView.Shortcut")));
			this.miSWOrbitView.ShowShortcut = ((bool)(resources.GetObject("miSWOrbitView.ShowShortcut")));
			this.miSWOrbitView.Text = resources.GetString("miSWOrbitView.Text");
			this.miSWOrbitView.Visible = ((bool)(resources.GetObject("miSWOrbitView.Visible")));
			this.miSWOrbitView.Click += new System.EventHandler(this.miSWIsometricView_Click);
			// 
			// miSEOrbitView
			// 
			this.miSEOrbitView.Enabled = ((bool)(resources.GetObject("miSEOrbitView.Enabled")));
			this.miSEOrbitView.Index = 8;
			this.miSEOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miSEOrbitView.Shortcut")));
			this.miSEOrbitView.ShowShortcut = ((bool)(resources.GetObject("miSEOrbitView.ShowShortcut")));
			this.miSEOrbitView.Text = resources.GetString("miSEOrbitView.Text");
			this.miSEOrbitView.Visible = ((bool)(resources.GetObject("miSEOrbitView.Visible")));
			this.miSEOrbitView.Click += new System.EventHandler(this.miSEIsometricView_Click);
			// 
			// miNEOrbitView
			// 
			this.miNEOrbitView.Enabled = ((bool)(resources.GetObject("miNEOrbitView.Enabled")));
			this.miNEOrbitView.Index = 9;
			this.miNEOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miNEOrbitView.Shortcut")));
			this.miNEOrbitView.ShowShortcut = ((bool)(resources.GetObject("miNEOrbitView.ShowShortcut")));
			this.miNEOrbitView.Text = resources.GetString("miNEOrbitView.Text");
			this.miNEOrbitView.Visible = ((bool)(resources.GetObject("miNEOrbitView.Visible")));
			this.miNEOrbitView.Click += new System.EventHandler(this.miNEIsometricView_Click);
			// 
			// miNWOrbitView
			// 
			this.miNWOrbitView.Enabled = ((bool)(resources.GetObject("miNWOrbitView.Enabled")));
			this.miNWOrbitView.Index = 10;
			this.miNWOrbitView.Shortcut = ((System.Windows.Forms.Shortcut)(resources.GetObject("miNWOrbitView.Shortcut")));
			this.miNWOrbitView.ShowShortcut = ((bool)(resources.GetObject("miNWOrbitView.ShowShortcut")));
			this.miNWOrbitView.Text = resources.GetString("miNWOrbitView.Text");
			this.miNWOrbitView.Visible = ((bool)(resources.GetObject("miNWOrbitView.Visible")));
			this.miNWOrbitView.Click += new System.EventHandler(this.miNWIsometricView_Click);
			// 
			// tlbRotateLeft
			// 
			this.tlbRotateLeft.Enabled = ((bool)(resources.GetObject("tlbRotateLeft.Enabled")));
			this.tlbRotateLeft.ImageIndex = ((int)(resources.GetObject("tlbRotateLeft.ImageIndex")));
			this.tlbRotateLeft.Text = resources.GetString("tlbRotateLeft.Text");
			this.tlbRotateLeft.ToolTipText = resources.GetString("tlbRotateLeft.ToolTipText");
			this.tlbRotateLeft.Visible = ((bool)(resources.GetObject("tlbRotateLeft.Visible")));
			// 
			// tlbRotateRight
			// 
			this.tlbRotateRight.Enabled = ((bool)(resources.GetObject("tlbRotateRight.Enabled")));
			this.tlbRotateRight.ImageIndex = ((int)(resources.GetObject("tlbRotateRight.ImageIndex")));
			this.tlbRotateRight.Text = resources.GetString("tlbRotateRight.Text");
			this.tlbRotateRight.ToolTipText = resources.GetString("tlbRotateRight.ToolTipText");
			this.tlbRotateRight.Visible = ((bool)(resources.GetObject("tlbRotateRight.Visible")));
			// 
			// tlbRotateAngle
			// 
			this.tlbRotateAngle.Enabled = ((bool)(resources.GetObject("tlbRotateAngle.Enabled")));
			this.tlbRotateAngle.ImageIndex = ((int)(resources.GetObject("tlbRotateAngle.ImageIndex")));
			this.tlbRotateAngle.Text = resources.GetString("tlbRotateAngle.Text");
			this.tlbRotateAngle.ToolTipText = resources.GetString("tlbRotateAngle.ToolTipText");
			this.tlbRotateAngle.Visible = ((bool)(resources.GetObject("tlbRotateAngle.Visible")));
			// 
			// tlbLay
			// 
			this.tlbLay.Enabled = ((bool)(resources.GetObject("tlbLay.Enabled")));
			this.tlbLay.ImageIndex = ((int)(resources.GetObject("tlbLay.ImageIndex")));
			this.tlbLay.Text = resources.GetString("tlbLay.Text");
			this.tlbLay.ToolTipText = resources.GetString("tlbLay.ToolTipText");
			this.tlbLay.Visible = ((bool)(resources.GetObject("tlbLay.Visible")));
			// 
			// tlbArcPoly
			// 
			this.tlbArcPoly.Enabled = ((bool)(resources.GetObject("tlbArcPoly.Enabled")));
			this.tlbArcPoly.ImageIndex = ((int)(resources.GetObject("tlbArcPoly.ImageIndex")));
			this.tlbArcPoly.Style = System.Windows.Forms.ToolBarButtonStyle.ToggleButton;
			this.tlbArcPoly.Tag = "";
			this.tlbArcPoly.Text = resources.GetString("tlbArcPoly.Text");
			this.tlbArcPoly.ToolTipText = resources.GetString("tlbArcPoly.ToolTipText");
			this.tlbArcPoly.Visible = ((bool)(resources.GetObject("tlbArcPoly.Visible")));
			// 
			// tlbBlackMode
			// 
			this.tlbBlackMode.Enabled = ((bool)(resources.GetObject("tlbBlackMode.Enabled")));
			this.tlbBlackMode.ImageIndex = ((int)(resources.GetObject("tlbBlackMode.ImageIndex")));
			this.tlbBlackMode.Style = System.Windows.Forms.ToolBarButtonStyle.ToggleButton;
			this.tlbBlackMode.Text = resources.GetString("tlbBlackMode.Text");
			this.tlbBlackMode.ToolTipText = resources.GetString("tlbBlackMode.ToolTipText");
			this.tlbBlackMode.Visible = ((bool)(resources.GetObject("tlbBlackMode.Visible")));
			// 
			// tlbColorMode
			// 
			this.tlbColorMode.Enabled = ((bool)(resources.GetObject("tlbColorMode.Enabled")));
			this.tlbColorMode.ImageIndex = ((int)(resources.GetObject("tlbColorMode.ImageIndex")));
			this.tlbColorMode.Style = System.Windows.Forms.ToolBarButtonStyle.ToggleButton;
			this.tlbColorMode.Text = resources.GetString("tlbColorMode.Text");
			this.tlbColorMode.ToolTipText = resources.GetString("tlbColorMode.ToolTipText");
			this.tlbColorMode.Visible = ((bool)(resources.GetObject("tlbColorMode.Visible")));
			// 
			// tlbDefSize
			// 
			this.tlbDefSize.Enabled = ((bool)(resources.GetObject("tlbDefSize.Enabled")));
			this.tlbDefSize.ImageIndex = ((int)(resources.GetObject("tlbDefSize.ImageIndex")));
			this.tlbDefSize.Text = resources.GetString("tlbDefSize.Text");
			this.tlbDefSize.ToolTipText = resources.GetString("tlbDefSize.ToolTipText");
			this.tlbDefSize.Visible = ((bool)(resources.GetObject("tlbDefSize.Visible")));
			// 
			// tlbTextShow
			// 
			this.tlbTextShow.Enabled = ((bool)(resources.GetObject("tlbTextShow.Enabled")));
			this.tlbTextShow.ImageIndex = ((int)(resources.GetObject("tlbTextShow.ImageIndex")));
			this.tlbTextShow.Text = resources.GetString("tlbTextShow.Text");
			this.tlbTextShow.ToolTipText = resources.GetString("tlbTextShow.ToolTipText");
			this.tlbTextShow.Visible = ((bool)(resources.GetObject("tlbTextShow.Visible")));
			// 
			// tlbDimShow
			// 
			this.tlbDimShow.Enabled = ((bool)(resources.GetObject("tlbDimShow.Enabled")));
			this.tlbDimShow.ImageIndex = ((int)(resources.GetObject("tlbDimShow.ImageIndex")));
			this.tlbDimShow.Text = resources.GetString("tlbDimShow.Text");
			this.tlbDimShow.ToolTipText = resources.GetString("tlbDimShow.ToolTipText");
			this.tlbDimShow.Visible = ((bool)(resources.GetObject("tlbDimShow.Visible")));
			// 
			// tlbSaveImageClip
			// 
			this.tlbSaveImageClip.Enabled = ((bool)(resources.GetObject("tlbSaveImageClip.Enabled")));
			this.tlbSaveImageClip.ImageIndex = ((int)(resources.GetObject("tlbSaveImageClip.ImageIndex")));
			this.tlbSaveImageClip.Text = resources.GetString("tlbSaveImageClip.Text");
			this.tlbSaveImageClip.ToolTipText = resources.GetString("tlbSaveImageClip.ToolTipText");
			this.tlbSaveImageClip.Visible = ((bool)(resources.GetObject("tlbSaveImageClip.Visible")));
			// 
			// tlbPrint
			// 
			this.tlbPrint.Enabled = ((bool)(resources.GetObject("tlbPrint.Enabled")));
			this.tlbPrint.ImageIndex = ((int)(resources.GetObject("tlbPrint.ImageIndex")));
			this.tlbPrint.Text = resources.GetString("tlbPrint.Text");
			this.tlbPrint.ToolTipText = resources.GetString("tlbPrint.ToolTipText");
			this.tlbPrint.Visible = ((bool)(resources.GetObject("tlbPrint.Visible")));
			// 
			// tlbSHX
			// 
			this.tlbSHX.Enabled = ((bool)(resources.GetObject("tlbSHX.Enabled")));
			this.tlbSHX.ImageIndex = ((int)(resources.GetObject("tlbSHX.ImageIndex")));
			this.tlbSHX.Text = resources.GetString("tlbSHX.Text");
			this.tlbSHX.ToolTipText = resources.GetString("tlbSHX.ToolTipText");
			this.tlbSHX.Visible = ((bool)(resources.GetObject("tlbSHX.Visible")));
			// 
			// tlbRect
			// 
			this.tlbRect.Enabled = ((bool)(resources.GetObject("tlbRect.Enabled")));
			this.tlbRect.ImageIndex = ((int)(resources.GetObject("tlbRect.ImageIndex")));
			this.tlbRect.Text = resources.GetString("tlbRect.Text");
			this.tlbRect.ToolTipText = resources.GetString("tlbRect.ToolTipText");
			this.tlbRect.Visible = ((bool)(resources.GetObject("tlbRect.Visible")));
			// 
			// tlbSelObject
			// 
			this.tlbSelObject.Enabled = ((bool)(resources.GetObject("tlbSelObject.Enabled")));
			this.tlbSelObject.ImageIndex = ((int)(resources.GetObject("tlbSelObject.ImageIndex")));
			this.tlbSelObject.Text = resources.GetString("tlbSelObject.Text");
			this.tlbSelObject.ToolTipText = resources.GetString("tlbSelObject.ToolTipText");
			this.tlbSelObject.Visible = ((bool)(resources.GetObject("tlbSelObject.Visible")));
			// 
			// tlbAxes
			// 
			this.tlbAxes.Enabled = ((bool)(resources.GetObject("tlbAxes.Enabled")));
			this.tlbAxes.ImageIndex = ((int)(resources.GetObject("tlbAxes.ImageIndex")));
			this.tlbAxes.Text = resources.GetString("tlbAxes.Text");
			this.tlbAxes.ToolTipText = resources.GetString("tlbAxes.ToolTipText");
			this.tlbAxes.Visible = ((bool)(resources.GetObject("tlbAxes.Visible")));
			// 
			// tlbOpenFromClipboard
			// 
			this.tlbOpenFromClipboard.Enabled = ((bool)(resources.GetObject("tlbOpenFromClipboard.Enabled")));
			this.tlbOpenFromClipboard.ImageIndex = ((int)(resources.GetObject("tlbOpenFromClipboard.ImageIndex")));
			this.tlbOpenFromClipboard.Text = resources.GetString("tlbOpenFromClipboard.Text");
			this.tlbOpenFromClipboard.ToolTipText = resources.GetString("tlbOpenFromClipboard.ToolTipText");
			this.tlbOpenFromClipboard.Visible = ((bool)(resources.GetObject("tlbOpenFromClipboard.Visible")));
			// 
			// tlbUseDoubleBuffering
			// 
			this.tlbUseDoubleBuffering.Enabled = ((bool)(resources.GetObject("tlbUseDoubleBuffering.Enabled")));
			this.tlbUseDoubleBuffering.ImageIndex = ((int)(resources.GetObject("tlbUseDoubleBuffering.ImageIndex")));
			this.tlbUseDoubleBuffering.Pushed = true;
			this.tlbUseDoubleBuffering.Text = resources.GetString("tlbUseDoubleBuffering.Text");
			this.tlbUseDoubleBuffering.ToolTipText = resources.GetString("tlbUseDoubleBuffering.ToolTipText");
			this.tlbUseDoubleBuffering.Visible = ((bool)(resources.GetObject("tlbUseDoubleBuffering.Visible")));
			// 
			// imgLstToolBtn
			// 
			this.imgLstToolBtn.ColorDepth = System.Windows.Forms.ColorDepth.Depth32Bit;
			this.imgLstToolBtn.ImageSize = ((System.Drawing.Size)(resources.GetObject("imgLstToolBtn.ImageSize")));
			this.imgLstToolBtn.ImageStream = ((System.Windows.Forms.ImageListStreamer)(resources.GetObject("imgLstToolBtn.ImageStream")));
			this.imgLstToolBtn.TransparentColor = System.Drawing.Color.Magenta;
			// 
			// pnlLayouts
			// 
			this.pnlLayouts.AccessibleDescription = resources.GetString("pnlLayouts.AccessibleDescription");
			this.pnlLayouts.AccessibleName = resources.GetString("pnlLayouts.AccessibleName");
			this.pnlLayouts.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("pnlLayouts.Anchor")));
			this.pnlLayouts.AutoScroll = ((bool)(resources.GetObject("pnlLayouts.AutoScroll")));
			this.pnlLayouts.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("pnlLayouts.AutoScrollMargin")));
			this.pnlLayouts.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("pnlLayouts.AutoScrollMinSize")));
			this.pnlLayouts.BackColor = System.Drawing.SystemColors.Control;
			this.pnlLayouts.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("pnlLayouts.BackgroundImage")));
			this.pnlLayouts.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.pnlLayouts.Controls.Add(this.lbLayouts);
			this.pnlLayouts.Controls.Add(this.cbLayouts);
			this.pnlLayouts.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("pnlLayouts.Dock")));
			this.pnlLayouts.Enabled = ((bool)(resources.GetObject("pnlLayouts.Enabled")));
			this.pnlLayouts.Font = ((System.Drawing.Font)(resources.GetObject("pnlLayouts.Font")));
			this.pnlLayouts.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("pnlLayouts.ImeMode")));
			this.pnlLayouts.Location = ((System.Drawing.Point)(resources.GetObject("pnlLayouts.Location")));
			this.pnlLayouts.Name = "pnlLayouts";
			this.pnlLayouts.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("pnlLayouts.RightToLeft")));
			this.pnlLayouts.Size = ((System.Drawing.Size)(resources.GetObject("pnlLayouts.Size")));
			this.pnlLayouts.TabIndex = ((int)(resources.GetObject("pnlLayouts.TabIndex")));
			this.pnlLayouts.Text = resources.GetString("pnlLayouts.Text");
			this.pnlLayouts.Visible = ((bool)(resources.GetObject("pnlLayouts.Visible")));
			// 
			// lbLayouts
			// 
			this.lbLayouts.AccessibleDescription = resources.GetString("lbLayouts.AccessibleDescription");
			this.lbLayouts.AccessibleName = resources.GetString("lbLayouts.AccessibleName");
			this.lbLayouts.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("lbLayouts.Anchor")));
			this.lbLayouts.AutoSize = ((bool)(resources.GetObject("lbLayouts.AutoSize")));
			this.lbLayouts.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("lbLayouts.Dock")));
			this.lbLayouts.Enabled = ((bool)(resources.GetObject("lbLayouts.Enabled")));
			this.lbLayouts.Font = ((System.Drawing.Font)(resources.GetObject("lbLayouts.Font")));
			this.lbLayouts.Image = ((System.Drawing.Image)(resources.GetObject("lbLayouts.Image")));
			this.lbLayouts.ImageAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lbLayouts.ImageAlign")));
			this.lbLayouts.ImageIndex = ((int)(resources.GetObject("lbLayouts.ImageIndex")));
			this.lbLayouts.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("lbLayouts.ImeMode")));
			this.lbLayouts.Location = ((System.Drawing.Point)(resources.GetObject("lbLayouts.Location")));
			this.lbLayouts.Name = "lbLayouts";
			this.lbLayouts.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("lbLayouts.RightToLeft")));
			this.lbLayouts.Size = ((System.Drawing.Size)(resources.GetObject("lbLayouts.Size")));
			this.lbLayouts.TabIndex = ((int)(resources.GetObject("lbLayouts.TabIndex")));
			this.lbLayouts.Text = resources.GetString("lbLayouts.Text");
			this.lbLayouts.TextAlign = ((System.Drawing.ContentAlignment)(resources.GetObject("lbLayouts.TextAlign")));
			this.lbLayouts.Visible = ((bool)(resources.GetObject("lbLayouts.Visible")));
			// 
			// cbLayouts
			// 
			this.cbLayouts.AccessibleDescription = resources.GetString("cbLayouts.AccessibleDescription");
			this.cbLayouts.AccessibleName = resources.GetString("cbLayouts.AccessibleName");
			this.cbLayouts.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("cbLayouts.Anchor")));
			this.cbLayouts.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("cbLayouts.BackgroundImage")));
			this.cbLayouts.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("cbLayouts.Dock")));
			this.cbLayouts.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.cbLayouts.Enabled = ((bool)(resources.GetObject("cbLayouts.Enabled")));
			this.cbLayouts.Font = ((System.Drawing.Font)(resources.GetObject("cbLayouts.Font")));
			this.cbLayouts.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("cbLayouts.ImeMode")));
			this.cbLayouts.IntegralHeight = ((bool)(resources.GetObject("cbLayouts.IntegralHeight")));
			this.cbLayouts.ItemHeight = ((int)(resources.GetObject("cbLayouts.ItemHeight")));
			this.cbLayouts.Location = ((System.Drawing.Point)(resources.GetObject("cbLayouts.Location")));
			this.cbLayouts.MaxDropDownItems = ((int)(resources.GetObject("cbLayouts.MaxDropDownItems")));
			this.cbLayouts.MaxLength = ((int)(resources.GetObject("cbLayouts.MaxLength")));
			this.cbLayouts.Name = "cbLayouts";
			this.cbLayouts.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("cbLayouts.RightToLeft")));
			this.cbLayouts.Size = ((System.Drawing.Size)(resources.GetObject("cbLayouts.Size")));
			this.cbLayouts.TabIndex = ((int)(resources.GetObject("cbLayouts.TabIndex")));
			this.cbLayouts.Tag = "-1";
			this.cbLayouts.Text = resources.GetString("cbLayouts.Text");
			this.cbLayouts.Visible = ((bool)(resources.GetObject("cbLayouts.Visible")));
			this.cbLayouts.SelectedIndexChanged += new System.EventHandler(this.cbLayouts_SelectedIndexChanged);
			// 
			// trvPanel
			// 
			this.trvPanel.AccessibleDescription = resources.GetString("trvPanel.AccessibleDescription");
			this.trvPanel.AccessibleName = resources.GetString("trvPanel.AccessibleName");
			this.trvPanel.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("trvPanel.Anchor")));
			this.trvPanel.AutoScroll = ((bool)(resources.GetObject("trvPanel.AutoScroll")));
			this.trvPanel.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("trvPanel.AutoScrollMargin")));
			this.trvPanel.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("trvPanel.AutoScrollMinSize")));
			this.trvPanel.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("trvPanel.BackgroundImage")));
			this.trvPanel.Controls.Add(this.trvEntity);
			this.trvPanel.Controls.Add(this.spPropGrid);
			this.trvPanel.Controls.Add(this.propGrid);
			this.trvPanel.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("trvPanel.Dock")));
			this.trvPanel.Enabled = ((bool)(resources.GetObject("trvPanel.Enabled")));
			this.trvPanel.Font = ((System.Drawing.Font)(resources.GetObject("trvPanel.Font")));
			this.trvPanel.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("trvPanel.ImeMode")));
			this.trvPanel.Location = ((System.Drawing.Point)(resources.GetObject("trvPanel.Location")));
			this.trvPanel.Name = "trvPanel";
			this.trvPanel.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("trvPanel.RightToLeft")));
			this.trvPanel.Size = ((System.Drawing.Size)(resources.GetObject("trvPanel.Size")));
			this.trvPanel.TabIndex = ((int)(resources.GetObject("trvPanel.TabIndex")));
			this.trvPanel.Text = resources.GetString("trvPanel.Text");
			this.trvPanel.Visible = ((bool)(resources.GetObject("trvPanel.Visible")));
			// 
			// trvEntity
			// 
			this.trvEntity.AccessibleDescription = resources.GetString("trvEntity.AccessibleDescription");
			this.trvEntity.AccessibleName = resources.GetString("trvEntity.AccessibleName");
			this.trvEntity.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("trvEntity.Anchor")));
			this.trvEntity.BackColor = System.Drawing.Color.Black;
			this.trvEntity.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("trvEntity.BackgroundImage")));
			this.trvEntity.BorderStyle = System.Windows.Forms.BorderStyle.None;
			this.trvEntity.CheckBoxes = true;
			this.trvEntity.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("trvEntity.Dock")));
			this.trvEntity.Enabled = ((bool)(resources.GetObject("trvEntity.Enabled")));
			this.trvEntity.Font = ((System.Drawing.Font)(resources.GetObject("trvEntity.Font")));
			this.trvEntity.ForeColor = System.Drawing.Color.White;
			this.trvEntity.ImageIndex = ((int)(resources.GetObject("trvEntity.ImageIndex")));
			this.trvEntity.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("trvEntity.ImeMode")));
			this.trvEntity.Indent = ((int)(resources.GetObject("trvEntity.Indent")));
			this.trvEntity.ItemHeight = ((int)(resources.GetObject("trvEntity.ItemHeight")));
			this.trvEntity.Location = ((System.Drawing.Point)(resources.GetObject("trvEntity.Location")));
			this.trvEntity.Name = "trvEntity";
			this.trvEntity.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("trvEntity.RightToLeft")));
			this.trvEntity.SelectedImageIndex = ((int)(resources.GetObject("trvEntity.SelectedImageIndex")));
			this.trvEntity.Size = ((System.Drawing.Size)(resources.GetObject("trvEntity.Size")));
			this.trvEntity.TabIndex = ((int)(resources.GetObject("trvEntity.TabIndex")));
			this.trvEntity.Text = resources.GetString("trvEntity.Text");
			this.trvEntity.Visible = ((bool)(resources.GetObject("trvEntity.Visible")));
			this.trvEntity.AfterCheck += new System.Windows.Forms.TreeViewEventHandler(this.trvEntity_AfterCheck);
			this.trvEntity.AfterSelect += new System.Windows.Forms.TreeViewEventHandler(this.trvEntity_AfterSelect);
			// 
			// spPropGrid
			// 
			this.spPropGrid.AccessibleDescription = resources.GetString("spPropGrid.AccessibleDescription");
			this.spPropGrid.AccessibleName = resources.GetString("spPropGrid.AccessibleName");
			this.spPropGrid.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("spPropGrid.Anchor")));
			this.spPropGrid.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("spPropGrid.BackgroundImage")));
			this.spPropGrid.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("spPropGrid.Dock")));
			this.spPropGrid.Enabled = ((bool)(resources.GetObject("spPropGrid.Enabled")));
			this.spPropGrid.Font = ((System.Drawing.Font)(resources.GetObject("spPropGrid.Font")));
			this.spPropGrid.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("spPropGrid.ImeMode")));
			this.spPropGrid.Location = ((System.Drawing.Point)(resources.GetObject("spPropGrid.Location")));
			this.spPropGrid.MinExtra = ((int)(resources.GetObject("spPropGrid.MinExtra")));
			this.spPropGrid.MinSize = ((int)(resources.GetObject("spPropGrid.MinSize")));
			this.spPropGrid.Name = "spPropGrid";
			this.spPropGrid.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("spPropGrid.RightToLeft")));
			this.spPropGrid.Size = ((System.Drawing.Size)(resources.GetObject("spPropGrid.Size")));
			this.spPropGrid.TabIndex = ((int)(resources.GetObject("spPropGrid.TabIndex")));
			this.spPropGrid.TabStop = false;
			this.spPropGrid.Visible = ((bool)(resources.GetObject("spPropGrid.Visible")));
			// 
			// propGrid
			// 
			this.propGrid.AccessibleDescription = resources.GetString("propGrid.AccessibleDescription");
			this.propGrid.AccessibleName = resources.GetString("propGrid.AccessibleName");
			this.propGrid.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("propGrid.Anchor")));
			this.propGrid.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("propGrid.BackgroundImage")));
			this.propGrid.CommandsVisibleIfAvailable = true;
			this.propGrid.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("propGrid.Dock")));
			this.propGrid.Enabled = ((bool)(resources.GetObject("propGrid.Enabled")));
			this.propGrid.Font = ((System.Drawing.Font)(resources.GetObject("propGrid.Font")));
			this.propGrid.HelpVisible = ((bool)(resources.GetObject("propGrid.HelpVisible")));
			this.propGrid.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("propGrid.ImeMode")));
			this.propGrid.LargeButtons = false;
			this.propGrid.LineColor = System.Drawing.SystemColors.ScrollBar;
			this.propGrid.Location = ((System.Drawing.Point)(resources.GetObject("propGrid.Location")));
			this.propGrid.Name = "propGrid";
			this.propGrid.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("propGrid.RightToLeft")));
			this.propGrid.Size = ((System.Drawing.Size)(resources.GetObject("propGrid.Size")));
			this.propGrid.TabIndex = ((int)(resources.GetObject("propGrid.TabIndex")));
			this.propGrid.Text = resources.GetString("propGrid.Text");
			this.propGrid.ViewBackColor = System.Drawing.SystemColors.Window;
			this.propGrid.ViewForeColor = System.Drawing.SystemColors.WindowText;
			this.propGrid.Visible = ((bool)(resources.GetObject("propGrid.Visible")));
			this.propGrid.PropertyValueChanged += new System.Windows.Forms.PropertyValueChangedEventHandler(this.propGrid_PropertyValueChanged);
			// 
			// spTree
			// 
			this.spTree.AccessibleDescription = resources.GetString("spTree.AccessibleDescription");
			this.spTree.AccessibleName = resources.GetString("spTree.AccessibleName");
			this.spTree.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("spTree.Anchor")));
			this.spTree.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("spTree.BackgroundImage")));
			this.spTree.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("spTree.Dock")));
			this.spTree.Enabled = ((bool)(resources.GetObject("spTree.Enabled")));
			this.spTree.Font = ((System.Drawing.Font)(resources.GetObject("spTree.Font")));
			this.spTree.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("spTree.ImeMode")));
			this.spTree.Location = ((System.Drawing.Point)(resources.GetObject("spTree.Location")));
			this.spTree.MinExtra = ((int)(resources.GetObject("spTree.MinExtra")));
			this.spTree.MinSize = ((int)(resources.GetObject("spTree.MinSize")));
			this.spTree.Name = "spTree";
			this.spTree.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("spTree.RightToLeft")));
			this.spTree.Size = ((System.Drawing.Size)(resources.GetObject("spTree.Size")));
			this.spTree.TabIndex = ((int)(resources.GetObject("spTree.TabIndex")));
			this.spTree.TabStop = false;
			this.spTree.Visible = ((bool)(resources.GetObject("spTree.Visible")));
			this.spTree.SplitterMoved += new System.Windows.Forms.SplitterEventHandler(this.spTree_SplitterMoved);
			// 
			// printPrevDlg
			// 
			this.printPrevDlg.AccessibleDescription = resources.GetString("printPrevDlg.AccessibleDescription");
			this.printPrevDlg.AccessibleName = resources.GetString("printPrevDlg.AccessibleName");
			this.printPrevDlg.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("printPrevDlg.Anchor")));
			this.printPrevDlg.AutoScaleBaseSize = ((System.Drawing.Size)(resources.GetObject("printPrevDlg.AutoScaleBaseSize")));
			this.printPrevDlg.AutoScroll = ((bool)(resources.GetObject("printPrevDlg.AutoScroll")));
			this.printPrevDlg.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("printPrevDlg.AutoScrollMargin")));
			this.printPrevDlg.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("printPrevDlg.AutoScrollMinSize")));
			this.printPrevDlg.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("printPrevDlg.BackgroundImage")));
			this.printPrevDlg.ClientSize = ((System.Drawing.Size)(resources.GetObject("printPrevDlg.ClientSize")));
			this.printPrevDlg.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("printPrevDlg.Dock")));
			this.printPrevDlg.Enabled = ((bool)(resources.GetObject("printPrevDlg.Enabled")));
			this.printPrevDlg.Font = ((System.Drawing.Font)(resources.GetObject("printPrevDlg.Font")));
			this.printPrevDlg.Icon = ((System.Drawing.Icon)(resources.GetObject("printPrevDlg.Icon")));
			this.printPrevDlg.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("printPrevDlg.ImeMode")));
			this.printPrevDlg.Location = ((System.Drawing.Point)(resources.GetObject("printPrevDlg.Location1")));
			this.printPrevDlg.MaximumSize = ((System.Drawing.Size)(resources.GetObject("printPrevDlg.MaximumSize")));
			this.printPrevDlg.MinimumSize = ((System.Drawing.Size)(resources.GetObject("printPrevDlg.MinimumSize")));
			this.printPrevDlg.Name = "printPrevDlg";
			this.printPrevDlg.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("printPrevDlg.RightToLeft")));
			this.printPrevDlg.StartPosition = ((System.Windows.Forms.FormStartPosition)(resources.GetObject("printPrevDlg.StartPosition")));
			this.printPrevDlg.Text = resources.GetString("printPrevDlg.Text");
			this.printPrevDlg.TransparencyKey = System.Drawing.Color.Empty;
			this.printPrevDlg.Visible = ((bool)(resources.GetObject("printPrevDlg.Visible")));
			// 
			// dlgSaveDXF
			// 
			this.dlgSaveDXF.DefaultExt = "*.dxf";
			this.dlgSaveDXF.Filter = resources.GetString("dlgSaveDXF.Filter");
			this.dlgSaveDXF.Title = resources.GetString("dlgSaveDXF.Title");
			// 
			// cadPictBox
			// 
			this.cadPictBox.AccessibleDescription = resources.GetString("cadPictBox.AccessibleDescription");
			this.cadPictBox.AccessibleName = resources.GetString("cadPictBox.AccessibleName");
			this.cadPictBox.Anchor = ((System.Windows.Forms.AnchorStyles)(resources.GetObject("cadPictBox.Anchor")));
			this.cadPictBox.BackColor = System.Drawing.Color.Black;
			this.cadPictBox.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("cadPictBox.BackgroundImage")));
			this.cadPictBox.BorderStyle = System.Windows.Forms.BorderStyle.FixedSingle;
			this.cadPictBox.Cursor = System.Windows.Forms.Cursors.Default;
			this.cadPictBox.Dock = ((System.Windows.Forms.DockStyle)(resources.GetObject("cadPictBox.Dock")));
			this.cadPictBox.DoubleBuffering = true;
			this.cadPictBox.Enabled = ((bool)(resources.GetObject("cadPictBox.Enabled")));
			this.cadPictBox.Font = ((System.Drawing.Font)(resources.GetObject("cadPictBox.Font")));
			this.cadPictBox.Image = ((System.Drawing.Image)(resources.GetObject("cadPictBox.Image")));
			this.cadPictBox.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("cadPictBox.ImeMode")));
			this.cadPictBox.Location = ((System.Drawing.Point)(resources.GetObject("cadPictBox.Location")));
			this.cadPictBox.Name = "cadPictBox";
			this.cadPictBox.Position = new System.Drawing.Point(0, 0);
			this.cadPictBox.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("cadPictBox.RightToLeft")));
			this.cadPictBox.Size = ((System.Drawing.Size)(resources.GetObject("cadPictBox.Size")));
			this.cadPictBox.SizeMode = ((System.Windows.Forms.PictureBoxSizeMode)(resources.GetObject("cadPictBox.SizeMode")));
			this.cadPictBox.TabIndex = ((int)(resources.GetObject("cadPictBox.TabIndex")));
			this.cadPictBox.TabStop = false;
			this.cadPictBox.Text = resources.GetString("cadPictBox.Text");
			this.cadPictBox.VirtualSize = new System.Drawing.Size(0, 0);
			this.cadPictBox.Visible = ((bool)(resources.GetObject("cadPictBox.Visible")));
			this.cadPictBox.Resize += new System.EventHandler(this.cadPictBox_Resize);
			this.cadPictBox.MouseUp += new System.Windows.Forms.MouseEventHandler(this.cadPictBox_MouseUp);
			this.cadPictBox.Paint += new System.Windows.Forms.PaintEventHandler(this.cadPictBox_Paint);
			this.cadPictBox.MouseMove += new System.Windows.Forms.MouseEventHandler(this.cadPictBox_MouseMove);
			this.cadPictBox.MouseDown += new System.Windows.Forms.MouseEventHandler(this.cadPictBox_MouseDown);
			// 
			// dlgOpenSerializeFile
			// 
			this.dlgOpenSerializeFile.Filter = resources.GetString("dlgOpenSerializeFile.Filter");
			this.dlgOpenSerializeFile.Title = resources.GetString("dlgOpenSerializeFile.Title");
			// 
			// dlgSaveSerializeFile
			// 
			this.dlgSaveSerializeFile.Filter = resources.GetString("dlgSaveSerializeFile.Filter");
			this.dlgSaveSerializeFile.Title = resources.GetString("dlgSaveSerializeFile.Title");
			// 
			// dlgOpenFile
			// 
			this.dlgOpenFile.DefaultExt = "*.dxf;*.dwg";
			this.dlgOpenFile.Filter = resources.GetString("dlgOpenFile.Filter");
			this.dlgOpenFile.ShowHelp = true;
			this.dlgOpenFile.Title = resources.GetString("dlgOpenFile.Title");
			// 
			// MainForm
			// 
			this.AccessibleDescription = resources.GetString("$this.AccessibleDescription");
			this.AccessibleName = resources.GetString("$this.AccessibleName");
			this.AutoScaleBaseSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScaleBaseSize")));
			this.AutoScroll = ((bool)(resources.GetObject("$this.AutoScroll")));
			this.AutoScrollMargin = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMargin")));
			this.AutoScrollMinSize = ((System.Drawing.Size)(resources.GetObject("$this.AutoScrollMinSize")));
			this.BackColor = System.Drawing.SystemColors.Control;
			this.BackgroundImage = ((System.Drawing.Image)(resources.GetObject("$this.BackgroundImage")));
			this.ClientSize = ((System.Drawing.Size)(resources.GetObject("$this.ClientSize")));
			this.Controls.Add(this.spTree);
			this.Controls.Add(this.cadPictBox);
			this.Controls.Add(this.stBar);
			this.Controls.Add(this.trvPanel);
			this.Controls.Add(this.pnlLayouts);
			this.Controls.Add(this.tlbTool);
			this.Enabled = ((bool)(resources.GetObject("$this.Enabled")));
			this.Font = ((System.Drawing.Font)(resources.GetObject("$this.Font")));
			this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
			this.ImeMode = ((System.Windows.Forms.ImeMode)(resources.GetObject("$this.ImeMode")));
			this.Location = ((System.Drawing.Point)(resources.GetObject("$this.Location")));
			this.MaximumSize = ((System.Drawing.Size)(resources.GetObject("$this.MaximumSize")));
			this.Menu = this.mainMenu;
			this.MinimumSize = ((System.Drawing.Size)(resources.GetObject("$this.MinimumSize")));
			this.Name = "MainForm";
			this.RightToLeft = ((System.Windows.Forms.RightToLeft)(resources.GetObject("$this.RightToLeft")));
			this.StartPosition = ((System.Windows.Forms.FormStartPosition)(resources.GetObject("$this.StartPosition")));
			this.Text = resources.GetString("$this.Text");
			this.WindowState = System.Windows.Forms.FormWindowState.Maximized;
			this.Closing += new System.ComponentModel.CancelEventHandler(this.MainForm_Closing);
			this.Load += new System.EventHandler(this.MainForm_Load);
			this.Deactivate += new System.EventHandler(this.MainForm_Deactivate);
			((System.ComponentModel.ISupportInitialize)(this.sbOpen)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.sbScale)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.sbCoord)).EndInit();
			this.pnlLayouts.ResumeLayout(false);
			this.trvPanel.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		[STAThread]
		static void Main(string[] args) 
		{
			Application.EnableVisualStyles();
			Application.DoEvents();			
			LoadParams(args);
			Application.ThreadException += new System.Threading.ThreadExceptionEventHandler(DoExceptionWorking);
			Application.Run(new MainForm());			
		}

		private static void DoExceptionWorking(object sender, System.Threading.ThreadExceptionEventArgs args)
		{				
			CADConst.SendExceptionReport(args.Exception);
		}

		private static void LoadParams(string[] args)
		{
			if(args.Length != 0)	
				openFileName = args[0];							
		}

		private string RealScale
		{
			get
			{
				if(cadImage != null)
					return string.Format("{0,2:F}%", (((this.VisibleAreaSize.Width * ImageScale) / this.cadImage.AbsWidth) * cadImage.MMToPixelX) * 100);
				else 
					return string.Format("{0}%", ImageScale);
			}
		}

		private double RealScaleDouble
		{
			get
			{
				if(cadImage != null)
					return ((this.VisibleAreaSize.Width * ImageScale) / this.cadImage.AbsWidth) * cadImage.MMToPixelX;
				else return ImageScale;
			}
		}

		#region Help
		/// <summary>
		/// Adjusts the image size according to the specified scale.
		/// </summary>
		/// <param name="i">A scale value.</param>
		/// <remarks>If the scale value is more than one the image size increases; otherwise, decreases.</remarks>
		#endregion Help
		public void Zoom(float i)
		{
			if(cadImage == null) 
				return;
			ImageScale = ImageScale * i;
			if(ImageScale < 0.005f) 
				ImageScale = 0.005f;				
			cadPictBox.Invalidate();				
		}

		private void Shift()
		{
			LeftImagePosition = PreviousPosition.X - (PreviousPosition.X - LeftImagePosition) * ImageScale / ImagePreviousScale;
			TopImagePosition = PreviousPosition.Y - (PreviousPosition.Y - TopImagePosition) * ImageScale / ImagePreviousScale;
			ImagePreviousScale = ImageScale;		
		}

		#region Help
		/// <summary>
		/// Initializes a new instance of the <see cref = "CADImportNetDemos.CADViewerDemo.MainForm">MainForm</see> class.
		/// </summary>
		#endregion Help
		public MainForm()
		{
			InitParams();
			InitializeComponent();
			InitExtParam();
		}

		private void InitParams()
		{
			showLineWeight = false;
			useSelectEntity = false;			
			useSHXFonts = false;
			ChangeTypeFont();
			textVisible = true;
			dimVisible = true;
			useWinEllipse = false;
			ImagePreviousScale = 1.0f;
			lngFile = ApplicationConstants.defaultstr;
			curLngIndex = 0;
			ImageScale = 1;
			drawMode = true;
			PreviousPosition = new PointF();			
			Orb3D = new Orbit3D();
			this.Orb3D.RotateEvent += new CADImport.FaceModule.CADImportEventHandler(this.ResizeLayout);
			lForm = new LayerForm();			
			aboutFrm = new AboutForm();
			shxFrm = new SHXForm();
			rasterSizeForm = new SetRasterSizeForm();
			openFromWebForm = new OpenFileFromWebForm();
			#region protect
#if (protect && floatprotect)
			floatLicFrm = new FloatLicForm();
			floatLicFrm.Change += new System.EventHandler(InvalidateImage);
#endif
#if protect
			regFrm = new RegForm();
#endif
			#endregion protect
			optForm = new OptionsForm();
			prtForm = new PrintingForm();
			this.prtForm.LayerForm = lForm;
			listItemSelectDel =  new ListItemSelectEventHandler(ListSelect);	
			this.useDoubleBuffering = true;		
		}

		private void InitExtParam()
		{
			Initial3DOrbit();
			#region protect
#if ((! floatprotect) && protect)
				this.miFloatLic.Enabled = false;
#endif
			#endregion
			InitLng();			
			InitSettings();
			SetAllFormsSettings();
			this.clipRectangle = new ClipRect(this.cadPictBox);		
			this.clipRectangle.MultySelect = false;
			this.miCopyAsBMP.Shortcut = Shortcut.CtrlC;
			CADImportFace.EntityPropertyGrid = this.propGrid;
			this.cadPictBox.MouseWheel += new MouseEventHandler(CADPictBoxMouseWheel);
			this.cadPictBox.ScrollEvent += new CADImport.FaceModule.ScrollEventHandlerExt(CADPictBoxScroll);			
		}

		private void CADPictBoxKeyDown(object sender, KeyEventArgs e)
		{	
			if(!this.cadPictBox.Focused)
				this.cadPictBox.Focus();	
			float cn = 10.0f;
			if(e.Shift)
				cn = 20.0f;
			switch(e.KeyCode)
			{					
				case Keys.Up:	
					this.TopImagePosition -= cn;
					this.cadPictBox.Invalidate();					
					SetPictureBoxPosition(Position);
					break;
				case Keys.Down:
					this.TopImagePosition += cn;
					this.cadPictBox.Invalidate();
					SetPictureBoxPosition(Position);
					break;
				case Keys.Left:
					this.LeftImagePosition -= cn;
					this.cadPictBox.Invalidate(); 
					SetPictureBoxPosition(Position);
					break;
				case Keys.Right:
					this.LeftImagePosition += cn;
					this.cadPictBox.Invalidate();
					SetPictureBoxPosition(Position);
					break;
			}
		}	
		
		private void CADPictBoxMouseWheel(object sender, System.Windows.Forms.MouseEventArgs e)
		{			
			if(e.Delta < 0)	
				Zoom(0.7f);
			else 
				Zoom(1.3f);
			this.Shift();
			SetPictureBoxPosition(Position);
		}

		private void CADPictBoxScroll(object sender, CADImport.FaceModule.ScrollEventArgsExt e)
		{			
			LeftImagePosition = -this.cadPictBox.Position.X;
			TopImagePosition = -this.cadPictBox.Position.Y;
			this.cadPictBox.Invalidate();
		}

		private void InitLng()
		{
			mlng = new MultipleLanguage(this.GetType());
			//Save value of NoName elements
			if(this.mainMenu != null)
				mlng.SaveNameMenuItem(this.mainMenu.MenuItems);
			if(this.ContextMenu != null)
				mlng.SaveNameMenuItem(this.ContextMenu.MenuItems);
			mlng.SaveNameNoNameElement(this.Controls);			
		}

		private void SetAllFormsSettings()
		{	
			SetAllFormsLanguageSettings();	
			this.optForm.SettingsList = settingsLst;								
			this.optForm.ChangeLngPath += new CADImport.CADImportForms.ChangeLngPathEventHandler(ReloadLNG);
			this.optForm.ChangeLanguage += new CADImport.CADImportForms.ChangeLanguageEventHandler(ChangeLanguage);
			this.optForm.ChangeEntityPanelVisible += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeTreeVisible);
			this.optForm.ChangeBackgroundColor += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeBackColor);
			this.optForm.ChangeDrawingColors += new CADImport.CADImportForms.ChangeOptionsEventHandler(ChangeDrawingColors);
		}

		private void ChangeDrawingColors(bool val)
		{
			if(val)
				this.DoNormalColor();				
			else
				this.DoBlackColor();				
		}

		private void ChangeBackColor(bool val)
		{
			if(val)
				this.Black_Click();
			else
				this.White_Click();
		}

		private void ChangeTreeVisible(bool val)
		{			
			ChangeTreeVisiblity(val);
		}
		
		private void SetAllFormsLanguageSettings()
		{
			this.optForm.MultipleLanguagesPath = mlng.Path;
			this.optForm.LngFileName = lngFile;			
			this.aboutFrm.MultipleLanguagesPath = mlng.Path;
			this.aboutFrm.LngFileName = lngFile;
			#region FloatingLic
			#if floatprotect
			this.floatLicFrm.MultipleLanguagesPath = mlng.Path;
			this.floatLicFrm.LngFileName = lngFile;
			#endif
			#endregion
			this.lForm.MultipleLanguagesPath = mlng.Path;
			this.lForm.LngFileName = lngFile;
			this.prtForm.MultipleLanguagesPath = mlng.Path;
			this.prtForm.LngFileName = lngFile;
			this.regFrm.MultipleLanguagesPath = mlng.Path;
			this.regFrm.LngFileName = lngFile;
			this.rasterSizeForm.MultipleLanguagesPath = mlng.Path;
			this.rasterSizeForm.LngFileName = lngFile;
			this.shxFrm.MultipleLanguagesPath = mlng.Path;
			this.shxFrm.LngFileName = lngFile;
		}

		private void InitSettings()
		{			
			svSet = new SaveSettings(fileSettingsName);
			settingsLst = svSet.LoadOptions();
			if(settingsLst != null)
			{
				string key = ApplicationConstants.languagepath;
				if(settingsLst.ContainsKey(key))
					this.mlng.Path = Convert.ToString(settingsLst[key]);
			} 
			else			
				this.mlng.Path = CADConst.lngPathDefault;			
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
			if(settingsLst == null)
				CreateNewSettingsList();
			else
				SetSettings();
		}

		private void Initial3DOrbit()
		{
			Orb3D.Parent = this.cadPictBox;
		}

		#region Help
		/// <summary>
		/// Cleans up any resources being used.
		/// </summary>
		/// <param name="disposing">A value indicating if both managed and unmanaged resources have to be released (<b>true</b>) or only unmanaged (<b>false</b>). 
		///</param>
		#endregion Help
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		private void miOpenFile_Click(object sender, System.EventArgs e)
		{
			this.ShowLoadFileDialog();	
			this.ChangeControlState();
		}

		private void DeactCADImage()
		{
			this.propGrid.SelectedObject = null;
			lForm.LayerList.Clear();
			lForm.LayerList.SelectItemEvent -= listItemSelectDel;			
		}
		#region Help 
		#if RUSHELP
		/// <summary>
		///        
		/// </summary>
		#else
		/// <summary>
		/// Invokes open file dialog and loads specified file
		/// </summary>
		#endif
		#endregion
		public void ShowLoadFileDialog()
		{
			DeactCADImage();
			this.cadPictBox.Enabled = false;
			if(dlgOpenFile.ShowDialog() != DialogResult.OK) 
			{
				cadPictBox.Visible = true;	
				this.cadPictBox.Enabled = true;
				return;
			}
			this.cadPictBox.Enabled = true;
			LoadFile(dlgOpenFile.FileName);			
		}

		#region Help
#if RUSHELP
		/// <summary>
		///     <see cref="MainForm.Image"/>CADImage    
		/// </summary>
#else
		/// <summary>
		/// Sets current properties for <see cref="MainForm.Image"/>CADImage for loading file
		/// </summary>
#endif
		#endregion
		public void SetCADImageOptions()
		{			
			cadImage.UseWinEllipse = false;		
			cadImage.IsShowLineWeight = false;
			cadImage.IsShowLineWeight = this.showLineWeight;		
			this.showLineWeight = false;			
			this.cadImage.UseDoubleBuffering = this.useDoubleBuffering;
			this.useSelectEntity = false;
			Orb3D.CADImage = cadImage;
			Orb3D.Visible = false;
			Orb3D.Disable3dOrbit();
			if(cadPictBox.BackColor == Color.White)
				White_Click();
			else 
				Black_Click();
			ViewLayouts();
			this.cadImage.IsDraw3DAxes = this.tlbAxes.Pushed;		
			this.Cursor = Cursors.Default;
			if(this.trvPanel.Visible == true) 
				CADImportFace.LoadTreeNodes(trvEntity.Nodes, cadImage);
			if(this.DrawMode == false) 
				this.DoBlackColor();			 			
			SetLayList();	
			ObjEntity.cadImage = cadImage;			
			this.prtForm.Image = this.cadImage;
			ObjEntity.propGrid = this.propGrid;		
			DoResize();			
			SetPictureBoxPosition(Position);		
		}

		#region Help
		/// <summary>
		/// Loads a CAD file.
		/// </summary>
		#endregion Help
		public void LoadFile(string fileName)
		{									
			if(fileName != null)
			{
				if(cadImage != null)
				{	
					cadImage.Dispose();
					cadImage = null;
					this.lForm.LayerList.Clear();
					lForm.LayerList.SelectItemEvent -= listItemSelectDel;			
				}
				this.Cursor = Cursors.WaitCursor;
				stBar.Panels[0].Text = ApplicationConstants.loadfilestr;
				ImageScale = 1.0f;
				ImagePreviousScale = 1.0f;
				Position = new PointF();				
				this.cadImage = CADImage.CreateImageByExtension(fileName);																
				if(this.cadImage is CADRasterImage)
					(this.cadImage as CADRasterImage).Control = this.cadPictBox;
			} 
			if(this.cadImage != null)
			{				
				CADImage.CodePage = System.Text.Encoding.Default.CodePage;
				CADImage.LastLoadedFilePath = Path.GetDirectoryName(fileName); 
				#region DebugInfo
#if DEBUG
				//DateTime d1, d2;
				//d1 = DateTime.Now;
#endif
				#endregion				
				if(CADConst.IsWebPath(fileName))
					this.cadImage.LoadFromWeb(fileName);
				else
					cadImage.LoadFromFile(fileName);
				#region DebugInfo
#if DEBUG			
				//d2 = DateTime.Now;
				//WriteTimeSpan(string.Format("LoadFromFile - {0}", fileName), @"E:\DebugInfo.txt", d1, d2);
#endif
				#endregion			
			}
			stBar.Panels[0].Text = Path.GetFileName(fileName) + ApplicationConstants.sepstr;						
			SetCADImageOptions();
		}

		private void NotSupportedInCurrentVersion()
		{
			this.Cursor = Cursors.Default;
			cadPictBox.Visible = true;
			stBar.Panels[0].Text = ApplicationConstants.notsupportedstr;
			MessageBox.Show(ApplicationConstants.notsupportedextstr, ApplicationConstants.appnamestr);
			return;
		}		

		#region Help
		/// <summary>
		/// Enables or disables buttons of the toolbar and menu items of the main menu.
		/// </summary>
		/// <param name="aVal"><b>true</b> if to enable the buttons and menu items; <b>false</b> if to disable them.</param>
		/// <remarks>The buttons and menu items are enabled after loading a CAD file and become disabled after closing the file.</remarks>
		#endregion Help
		public void EnableButton(bool aVal)
		{
			for(int i = 1; i < 24; i++)
				tlbTool.Buttons[i].Enabled = aVal;
			cbLayouts.Enabled = aVal;
			miScale.Enabled = aVal;
			miSaveFile.Enabled = aVal;
			miCopyAsBMP.Enabled = aVal;
			miZoomIn.Enabled = aVal;
			miZoomOut.Enabled = aVal;
			miFitToWindow.Enabled = aVal;
			miDrawNormalColor.Enabled = aVal;
			miDrawBlackColor.Enabled = aVal;
			miWhiteBackground.Enabled = aVal;
			miBlackBackground.Enabled = aVal;
			miChangeBackgroundColor.Enabled = aVal;
			miShowLineWeight.Enabled = aVal;
			miArcsSplit.Enabled = aVal;
			miDimShow.Enabled = aVal;
			miTextsShow.Enabled = aVal;
			miLayersShow.Enabled = aVal;
			mi3DViews.Enabled = aVal;
			miEnable3DOrbit.Enabled = aVal;
			miClosePicture.Enabled = aVal;
			miPrint.Enabled = aVal;
			miPrintPreview.Enabled = aVal;
			miCustomPrint.Enabled = aVal;
			#region Export
#if Export
			miSaveAsDXF.Enabled = aVal;
#endif
			#endregion
		}

		private void miZoomIn_Click(object sender, System.EventArgs e)
		{
			DoZoomIn();
		}

		#region Help
		/// <summary>
		/// Increases a scale of the CAD image in two times.
		/// </summary>
		#endregion Help
		public void DoZoomIn()
		{
			if(cadImage == null) return;
			PreviousPosition = new PointF(cadPictBox.ClientRectangle.Width / 2.0f, cadPictBox.ClientRectangle.Height / 2.0f);
			ImageScale = ImageScale * 2.0f;
			cadPictBox.Invalidate();
			this.Shift();
			SetPictureBoxPosition(Position);
		}

		private void miZoomOut_Click(object sender, System.EventArgs e)
		{
			DoZoomOut();
		}

		#region Help
		/// <summary>
		/// Decreases a ImageScale of the CAD image in two times.
		/// </summary>
		#endregion Help
		public void DoZoomOut()
		{
			if(cadImage == null) return;
			PreviousPosition = new PointF(cadPictBox.ClientRectangle.Width / 2.0f, cadPictBox.ClientRectangle.Height / 2.0f);
			ImageScale = ImageScale / 2.0f;
			cadPictBox.Invalidate();
			this.Shift();
			SetPictureBoxPosition(Position);
		}

		private void cadPictBox_Paint(object sender, System.Windows.Forms.PaintEventArgs e)
		{				
			if(cadImage == null) return;
			#region TestCode
			#if DEBUG
				//DateTime d1, d2;
				//d1 = DateTime.Now;
			#endif
			#endregion													
				DrawCADImage(e.Graphics);
				stBar.Panels[1].Text = RealScale;							
			#region TestCode
			#if DEBUG			
				//d2 = DateTime.Now;
				//WriteTimeSpan(string.Format("DrawCADImage - {0}", this.cadImage.Converter.Source), @"E:\DebugInfo.txt", d1, d2);
			#endif
			#endregion
		}

		#region Help
		/// <summary>
		/// Draws a CAD image from the loaded CAD file.
		/// </summary>
		/// <param name="gr">A <see cref="System.Drawing.Graphics">Graphics</see> object used to draw the CAD entities.</param>
		#endregion Help
		public void DrawCADImage(Graphics gr)
		{						
			try
			{								
				Shift();
				RectangleF tmp = ImageRectangleF;											
				SetSizePictureBox(new Size((int)tmp.Width, (int)tmp.Height));																								
				cadImage.Draw(gr, tmp);								
			}
			catch
			#region Debug
			#if DEBUG
				(Exception e1)
			#endif
			{ 				
				return;
			}
			#endregion
		}

		#region Help
		#if RUSHELP
		/// <summary>
		///      <see cref="CADImport.FaceModule.CADPictureBox">CADPictureBox</see>
		/// </summary>
		/// <param name="sz"> </param>
		#else
		/// <summary>
		/// Sets scroll region for <see cref="CADImport.FaceModule.CADPictureBox">CADPictureBox</see>
		/// </summary>
		/// <param name="sz">Size to set</param>
		#endif
		#endregion
		public void SetSizePictureBox(Size sz)
		{		
			this.cadPictBox.SetVirtualSizeNoInvalidate(sz);			
		}

		private void SetPictureBoxPosition(PointF value)
		{
			int w1, h1;
			if(value.X > 0)
				w1 = 0;
			else
				w1 = (int)Math.Abs(value.X);
			if(w1 > this.cadPictBox.VirtualSize.Width)
				w1 = this.cadPictBox.VirtualSize.Width;
			if(value.Y > 0)
				h1 = 0;
			else
				h1 = (int)Math.Abs(value.Y);
			if(h1 > this.cadPictBox.VirtualSize.Height)
				h1 = this.cadPictBox.VirtualSize.Height;
			this.cadPictBox.SetPositionNoInvalidate(new Point(w1, h1));
		}

		private void cadPictBox_MouseUp(object sender, System.Windows.Forms.MouseEventArgs e)
		{
			detRMouseDown = false;
			cadPictBox.Cursor = Cursors.Default;
			if(this.clipRectangle.Enabled)
				if((this.clipRectangle.Type == RectangleType.Zooming))
				{					
					if((this.clipRectangle.ClientRectangle.Width <= 5)||(this.clipRectangle.ClientRectangle.Height <= 5)) 
						return;
					if(MultipleSelect())
						return;
					if(this.ImageScale > 1000.0f) 
						return; 
					float tmp1 = this.visibleArea.Width / this.clipRectangle.ClientRectangle.Width;
					float tmp2 = this.visibleArea.Height / this.clipRectangle.ClientRectangle.Height;
					if(tmp1 > tmp2) 
						tmp1 = tmp2;
					LeftImagePosition += this.clipRectangle.ClientRectangle.Width / 2.0f; 
					TopImagePosition += this.clipRectangle.ClientRectangle.Height / 2.0f; 					
					this.Zoom(tmp1);
				}			
		}

		private bool MultipleSelect()
		{
			if(cadImage.SelectionMode == SelectionEntityMode.Enabled)
			{
				int l = this.clipRectangle.ClientRectangle.Left;
				int t = this.clipRectangle.ClientRectangle.Top;				
				DPoint pt1 = this.GetRealPoint(l, t);
				DPoint pt2 = this.GetRealPoint(this.clipRectangle.ClientRectangle.Right, this.clipRectangle.ClientRectangle.Bottom);
				DRect tmpRect = new DRect(pt1.X, pt1.Y, pt2.X, pt2.Y);				
				Region rg = cadImage.GetSelectEntityRegion(new Rectangle(l, t, this.clipRectangle.ClientRectangle.Width, this.clipRectangle.ClientRectangle.Height));			
				cadImage.MultipleSelect(tmpRect, true, true);								
				cadPictBox.Invalidate(rg);
				rg.Dispose();
				return true;
			}
			return false;
		}

		private void cadPictBox_MouseDown(object sender, System.Windows.Forms.MouseEventArgs e)
		{
			if(this.cadImage == null) 
				return;
			if(e.Button == MouseButtons.Left)
			{
				if((this.cadImage.SelectionMode == SelectionEntityMode.Enabled) && useSelectEntity)
				{					
					if(cadImage.Select(e.X, e.Y))
					{
						cadPictBox.Invalidate(cadImage.GetSelectEntityRegion(this.cadPictBox.ClientRectangle));						
						return;
					}
					cadPictBox.Invalidate(cadImage.GetSelectEntityRegion(this.cadPictBox.ClientRectangle));					
				}
			}
			else
			{
				if((e.Button == MouseButtons.Right)||(e.Button == MouseButtons.Middle))
				{
					MainForm.ActiveForm.Cursor = Cursors.Hand;
					cX = e.X;
					cY = e.Y;
					detRMouseDown = true;
					return;
				}		
			}
			if((! this.clipRectangle.Enabled)&&(this.cadImage != null)&&(! this.Orb3D.Visible))	
				this.clipRectangle.EnableRect(RectangleType.Zooming, new Rectangle(e.X, e.Y, 0, 0));						
		}

		private void cadPictBox_MouseMove(object sender, System.Windows.Forms.MouseEventArgs e)
		{
			if(!this.cadPictBox.Focused)
				this.cadPictBox.Focus();				
			if(cadImage == null) 
				return;
			if((detRMouseDown)&&(!Orb3D.Visible))
			{
				LeftImagePosition -= (cX - e.X);
				TopImagePosition -= (cY - e.Y);				
				cX = e.X;
				cY = e.Y;
				cadPictBox.Invalidate();
				SetPictureBoxPosition(Position);
			}
			PreviousPosition = new PointF(e.X, e.Y);
			DPoint vPt = GetRealPoint(e.X, e.Y);
			stBar.Panels[2].Text = vPt.X.ToString() + ApplicationConstants.sepstr2 + vPt.Y.ToString() + 
								   ApplicationConstants.sepstr2 + vPt.Z.ToString();			
		}

		#region Help
		/// <summary>
		/// Gets a three-dimensional point of the current CAD image from the specified screen point.
		/// </summary>
		/// <param name="x">An X coordinate of the screen point.</param>
		/// <param name="y">A Y coordinate of the screen point.</param>
		/// <returns>A three-dimensional point.</returns>
		#endregion Help
		public DPoint GetRealPoint(int x, int y)
		{			
			RectangleF tmpRect = ImageRectangleF;	
			return CADConst.GetRealPoint(x, y, this.cadImage, tmpRect);
		}	
		
		#region Help
		/// <summary>
		/// Invokes a <see cref="System.Windows.Forms.SaveFileDialog">SaveFileDialog</see> box where 
		/// a user can select a directory and format for saving the current CAD image.
		/// </summary>
		/// <remarks><p>This method can be invoked from the toolbar and from the main menu.</p>
		/// <p>Images can be saved in the following formats: JPG, BMP, TIFF, GIF, EMF.</p></remarks>
		#endregion Help
		public void SaveAsImage()
		{
			if(cadImage == null) 
				return;
			if(this.cadImage.FileInf != null)
				dlgSaveImg.FileName = this.cadImage.FileInf.Name.Replace(this.cadImage.FileInf.Extension, string.Empty);
			if(dlgSaveImg.ShowDialog() != DialogResult.OK) 
				return;
			DRect tmpRect = new DRect(0, 0, VisibleAreaSize.Width * ImageScale, VisibleAreaSize.Height * ImageScale);
			ImageFormat imgFrm = ImageFormat.Bmp;
			if(dlgSaveImg.FileName != null) 
			{
				string tmp = dlgSaveImg.FileName;	
				if(tmp.ToUpper().IndexOf(ApplicationConstants.jpgextstr) != -1)
					imgFrm = ImageFormat.Jpeg;
				if(tmp.ToUpper().IndexOf(ApplicationConstants.bmpextstr) != -1)
					imgFrm = ImageFormat.Bmp;
				if(tmp.ToUpper().IndexOf(ApplicationConstants.tiffextstr) != -1)
					imgFrm = ImageFormat.Tiff;
				if(tmp.ToUpper().IndexOf(ApplicationConstants.gifextstr) != -1)
					imgFrm = ImageFormat.Gif;
				if(tmp.ToUpper().IndexOf(ApplicationConstants.emfextstr) != -1)
					imgFrm = ImageFormat.Emf;
				if(tmp.ToUpper().IndexOf(ApplicationConstants.wmfextstr) != -1)
					imgFrm = ImageFormat.Wmf;
				if(tmp.ToUpper().IndexOf(ApplicationConstants.pngextstr) != -1)
					imgFrm = ImageFormat.Png;				
				if(tmp.ToUpper().IndexOf(ApplicationConstants.dxfextstr) != -1)
				{
					SaveAsDXF(dlgSaveImg.FileName);
					return;
				}
			}			
			if(! this.clipRectangle.Enabled)
			{
				rasterSizeForm.Image = this.cadImage;
				rasterSizeForm.CurrentSize = tmpRect;
				rasterSizeForm.SaveFileName = dlgSaveImg.FileName;
				if(rasterSizeForm.ShowDialog() == DialogResult.OK)
					tmpRect = rasterSizeForm.SizeImage;
			}						
			int tmpNumberOfPartsInCircle = this.cadImage.NumberOfPartsInCircle;
			this.cadImage.NumberOfPartsInCircle = CADConst.SetNumberOfPartsInCurve(tmpRect);
			if(this.clipRectangle.Enabled)
			{				
				if((imgFrm == ImageFormat.Emf)||(imgFrm == ImageFormat.Wmf))				
					cadImage.ExportToMetafile(dlgSaveImg.FileName, tmpRect, this.clipRectangle.ClientRectangle);				
				else
					cadImage.SaveToFile(dlgSaveImg.FileName, imgFrm, tmpRect, this.clipRectangle.ClientRectangle, rasterSizeForm.ImagePixelFormat);				
			}
			else
			{				
				if((imgFrm == ImageFormat.Emf)||(imgFrm == ImageFormat.Wmf))
					cadImage.ExportToMetafile(dlgSaveImg.FileName, tmpRect);
				else
					cadImage.SaveToFile(dlgSaveImg.FileName, imgFrm, tmpRect, rasterSizeForm.ImagePixelFormat);				
			}						
			this.cadImage.NumberOfPartsInCircle = tmpNumberOfPartsInCircle;
		}	

		private void miZoom_Click(object sender, System.EventArgs e)
		{
			if(cadImage == null) 
				return;
			float i = ImageScale;
			switch((sender as MenuItem).Index)
			{
				case 0:
					i = 0.1f;
					break;
				case 1:
					i = 0.25f;
					break;
				case 2:
					i = 0.5f;
					break;
				case 3:
					i = 1.0f;
					break;
				case 4:
					i = 2.0f;
					break;
				case 5:
					i = 4.0f;
					break;
				case 6:
					i = 8.0f;
					break;
			}
			ResetScaling();
			this.PreviousPosition = new PointF(cadPictBox.ClientRectangle.Width / 2.0f, cadPictBox.ClientRectangle.Height / 2.0f);
			ImageScale = i;
			cadPictBox.Invalidate();
			SetPictureBoxPosition(Position);	
		}

		#region Help
		/// <summary>
		/// Paints the CAD image background in the white color.
		/// </summary>
		#endregion Help
		public void White_Click()
		{
			cadPictBox.BackColor = Color.White;			
			this.trvEntity.BackColor = Color.White;
			this.trvEntity.ForeColor = Color.Black;
			if(cadImage != null)
			{
				cadImage.DefaultColor = Color.Black;
				cadImage.BackgroundColor = Color.White;
			}
			if(this.clipRectangle != null)
				this.clipRectangle.Color = Color.Black;
		}

		private void ChangeControlState()
		{
			bool detNullImg = cadImage != null;
			EnableButton(detNullImg);
			bool tmp = false;
			if(cadPictBox.BackColor == Color.White)
				tmp = true;
			miWhiteBackground.Checked = tmp;
			miBlackBackground.Checked = ! tmp;
			if(detNullImg)
			{
				this.tlbWhite.Pushed = tmp;
				this.tlbBlack.Pushed = ! tmp;				
			}
			else 
			{
				this.tlbWhite.Pushed = false;
				this.tlbBlack.Pushed = false;				
			}
			tmp = this.textVisible;			
			if(detNullImg)
				this.tlbTextShow.Pushed = tmp;
			else
				this.tlbTextShow.Pushed = false;
			if(! tmp)
				this.tlbTextShow.ImageIndex = 15;
			else
				this.tlbTextShow.ImageIndex = 14;
			miTextsShow.Checked = tmp;
			tmp = this.dimVisible;
			if(detNullImg)
				this.tlbDimShow.Pushed = tmp;
			else 
				this.tlbDimShow.Pushed = false;
			if(! tmp)
				this.tlbDimShow.ImageIndex = 17;
			else 
				this.tlbDimShow.ImageIndex = 16;
			miDimShow.Checked = tmp;
			tmp = this.Orb3D.Visible;			
			this.tlb3d.Pushed = tmp;
			miEnable3DOrbit.Checked = tmp;
			miShowEntityTree.Checked = this.trvEntity.Visible;
			tmp = this.DrawMode;
			if(detNullImg)
			{				
				this.tlbBlackMode.Pushed = ! tmp;
				this.tlbColorMode.Pushed = tmp;
			}
			else
			{
				this.tlbBlackMode.Pushed = false;
				this.tlbColorMode.Pushed = false;
			}
			miDrawNormalColor.Checked = tmp;
			miDrawBlackColor.Checked = ! tmp;
			tmp = this.useWinEllipse;			
			if(detNullImg)
				this.tlbArcPoly.Pushed = ! tmp;
			else 
				this.tlbArcPoly.Pushed = false;
			miArcsSplit.Checked = ! tmp;
			miShowLineWeight.Checked = this.showLineWeight;
			if(curLngIndex < this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count)
				this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[curLngIndex].Checked = false;
			if(this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count > this.curLngIndex)
				this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[this.curLngIndex].Checked = true;
			if(detNullImg)
				this.tlbSelObject.Pushed = this.useSelectEntity;
			else
				this.tlbSelObject.Pushed = false;
			if(detNullImg)
				this.tlbSHX.Pushed = this.useSHXFonts;
			else
				this.tlbSHX.Pushed = false;
			this.tlbUseDoubleBuffering.Pushed = this.useDoubleBuffering;			
			if(this.useDoubleBuffering)
				this.tlbUseDoubleBuffering.ImageIndex = 29;
			else
				this.tlbUseDoubleBuffering.ImageIndex = 30;

		}

		#region Help
		/// <summary>
		/// Paints the CAD image background in the black color.
		/// </summary>
		#endregion Help
		public void Black_Click()
		{
			cadPictBox.BackColor = Color.Black;
			this.trvEntity.BackColor = Color.Black;
			this.trvEntity.ForeColor = Color.White;
			if(cadImage != null)
			{
				cadImage.DefaultColor = Color.White;
				cadImage.BackgroundColor = Color.Black;
			}
			if(this.clipRectangle != null)
				this.clipRectangle.Color = Color.White;
		}

		#region Help
		/// <summary>
		/// Paints the CAD image background in the user defined color.
		/// </summary>
		#endregion Help
		public void Color_Click()
		{
			if(dlgSetColor.ShowDialog() == DialogResult.OK)
			{
				cadPictBox.BackColor = dlgSetColor.Color;
				if(this.cadImage != null)
					this.cadImage.BackgroundColor = dlgSetColor.Color;
			}
		}

		private void tlbTool_ButtonClick(object sender, System.Windows.Forms.ToolBarButtonClickEventArgs e)
		{
			if((cadImage == null)&&(tlbTool.Buttons.IndexOf(e.Button) == 8)) return;
			switch(tlbTool.Buttons.IndexOf(e.Button))
			{
				case 0:
					this.ShowLoadFileDialog();
					break; 
				case 1:
					DoZoomIn();
					break; 
				case 2:
					DoZoomOut();
					break;
				case 3:
					SaveAsImage();
					break;
				case 4:
					White_Click();
					break;
				case 5:
					Black_Click();
					break;
				case 6:
					Color_Click();
					break;
				case 7:
					Go3dOrbit(! this.Orb3D.Visible);
					break;
				case 8:					
					this.Rotate2D(90.0f);
					break;
				case 9:
					this.Rotate2D(-90.0f);
					break;
				case 10:
					this.Rotate2D(10.0f);
					break;
				case 11:
					SetLayList();
					lForm.ShowDialog();
					break;
				case 12:
					UseWinEllipse();
					break;
				case 13:
					DoBlackColor();
					break;
				case 14:
					DoNormalColor();
					break;
				case 15:
					ResetScaling();
					break;
				case 16:
					ChangeTextsVisiblity();
					break;
				case 17:
					ChangeDimensionsVisiblity();
					break;
				case 18:
					PutToClipboard();
					break;
				case 19:
					cadImage.Print(true, true);
					break;
				case 20:
					ChangeTypeFont();
					break;
				case 21:
					DoEnableRectangle(! this.clipRectangle.Enabled);
					break;
				case 22:
					this.useSelectEntity = ! this.useSelectEntity;
					ChangeSelectionCond(true);
					break;
				case 23:
					this.cadImage.IsDraw3DAxes = ! this.cadImage.IsDraw3DAxes;								
					this.cadPictBox.Invalidate();
					break;			
				case 24:
					GetFromClipboard();
					break;
				case 25:
					this.useDoubleBuffering = ! this.useDoubleBuffering;
					this.ChangeDoubleBufferingMode();							
					break;
			}
			this.ChangeControlState();
		}

		private void Rotate2D(float angle)
		{			
			this.cadImage.Rotate(Axes.Z, angle);			
			this.cadImage.GetExtents();
			this.cadImage.ClearBuffer();
			this.DoResize();			
		}

		internal void GetFromClipboard()
		{
			if(this.cadImage == null)
				this.CreateNewImage();			
			Image img = GetImageFromClipboard();
			if(img == null)
				return;
			this.cadImage = new CADRasterImage();
			((CADRasterImage)this.cadImage).LoadFromImage(img);

			if(cadPictBox.BackColor == Color.White)
				White_Click();
			else 
				Black_Click();
			ResizeLayout();
		}

		private Image GetImageFromClipboard()
		{
			DataObject objTmp = (DataObject)Clipboard.GetDataObject();			
			Image img = (Bitmap)objTmp.GetData(typeof(Bitmap));			
			return img;
		}

		private void ChangeSelectionCond(bool invalidate)
		{					
			if(this.useSelectEntity) 
			{								
				cadImage.SelectionMode = SelectionEntityMode.Enabled;
				this.clipRectangle.MultySelect = true;				
			}
			else
			{
				cadImage.SelectionMode = SelectionEntityMode.Disabled;
				this.clipRectangle.MultySelect = false;		
				this.showLineWeight = false;
			}				
			this.useDoubleBuffering = (! this.useSelectEntity) && (this.useDoubleBuffering);		
			this.ChangeDoubleBufferingMode();			
			if(invalidate)
				this.cadPictBox.Invalidate();
		}

		private void ChangeTypeFont()
		{
			this.useSHXFonts = ! this.useSHXFonts;
			CADConst.UseSHXFonts = this.useSHXFonts;
			if(this.useSHXFonts)
				DoSHXFonts();
			else
				DoTTFFonts();
			if(this.cadImage != null)
				ReOpen();
		}

		private void PutToClipboard()
		{
			if(this.clipRectangle.Enabled)
			{
				DRect tmpRect = ImageDRect;
				cadImage.SaveImageToClipboard(tmpRect, this.clipRectangle.ClientRectangle);
			}
			else
			{
				DRect tmp = new DRect(0.0, 0.0, VisibleAreaSize.Width*ImageScale, VisibleAreaSize.Height*ImageScale);
				cadImage.SaveImageToClipboard(tmp);
			}
		}

		private void DoEnableRectangle(bool val)
		{
			if(val)
			{
				Go3dOrbit(false);
				this.clipRectangle.Color = cadImage.DefaultColor;
				this.clipRectangle.EnableRect(RectangleType.Selecting);
			}
			else this.clipRectangle.DisableRect();
			this.tlbRect.Pushed = val;
		}

		private void DoSHXFonts()
		{
			CADConst.UseTTFFonts = false;
			CADConst.UseMultyTTFFonts = false;
		}

		private void DoTTFFonts()
		{
			CADConst.UseTTFFonts = true;
			CADConst.UseMultyTTFFonts = true;
		}

		#region Help
		/// <summary>
		/// Shows or hides 3D axes.
		/// </summary>
		#endregion Help
		public void Change3DAxesVisiblity()
		{
			cadImage.IsDraw3DAxes = !cadImage.IsDraw3DAxes;
			this.tlbAxes.Pushed = cadImage.IsDraw3DAxes;
			cadPictBox.Invalidate();
		}

		#region Help
		/// <summary>
		/// Shows or hides texts in the current CAD image.
		/// </summary>
		#endregion Help
		public void ChangeTextsVisiblity()
		{
			this.textVisible = ! this.textVisible;
			this.cadImage.TextVisible = this.textVisible;
			cadPictBox.Invalidate();			
		}
		
		#region Help
		/// <summary>
		/// Shows or hides dimensions in the current CAD image.
		/// </summary>
		#endregion Help
		public void ChangeDimensionsVisiblity()
		{
			this.dimVisible = ! this.dimVisible;
			this.cadImage.DimensionsVisible = this.dimVisible;
			cadPictBox.Invalidate();
		}

		#region Help
		/// <summary>
		/// Reopens a file after selecting or deselecting SHX fonts. 
		/// </summary>
		/// <remarks>This method is also called when the paths to the files containing 
		/// SHX fonts have been edited in the <b>SHX Paths</b> window invoked by the <b>SHX Fonts</b> menu item.
		/// </remarks>
		#endregion Help
		public void ReOpen()
		{
			if(dlgOpenFile.FileName != null)
				if(File.Exists(dlgOpenFile.FileName))
					this.LoadFile(dlgOpenFile.FileName);
		}

		#region Help
		/// <summary>
		/// Sets the scale and position of the current CAD image to its original values.
		/// </summary>
		#endregion Help
		public void ResetScaling()
		{
			ImageScale = 1.0f;
			ImagePreviousScale = 1.0f;
			LeftImagePosition = (cadPictBox.ClientRectangle.Width - VisibleAreaSize.Width) / 2.0f;
			TopImagePosition = (cadPictBox.ClientRectangle.Height - VisibleAreaSize.Height) / 2.0f;
			cadPictBox.Invalidate();
		}

		private void AddRecordToLayerList(string name, Color color, bool visible, bool freeze)
		{
			ListItem lstItem = new ListItem();			
			lstItem.Text = name;								
			lForm.LayerList.Items.Add(lstItem);
			lstItem = new ListItem();
			if(visible)				
				lstItem.ImageIndex = 7;							
			else
				lstItem.ImageIndex = 8;							
			lForm.LayerList.Items.Add(lstItem);
			lstItem = new ListItem();
			if(freeze)
				lstItem.ImageIndex = 3;				
			else
				lstItem.ImageIndex = 4;				
			lForm.LayerList.Items.Add(lstItem);	
			lstItem = new ListItem();
			lstItem.DrawColorRect = true;
			lstItem.BackColor = color;			
			lForm.LayerList.Items.Add(lstItem);			
		}
		#region Help
		#if RUSHELP
		/// <summary>
		///    <see cref="CADImport.CADLayer">CADLayer </see>
		/// </summary>
		/// <param name="visible"> </param>
		/// <param name="index">    </param>
		#else
		/// <summary>
		/// Sets <see cref="CADImport.CADLayer.Visible">CADLayer.Visible</see> parameter for the layer
		/// by the specified <see cref="CADImport.CADLayer">layer</see> index
		/// </summary>
		/// <param name="visible">Setting value</param>
		/// <param name="index">An index of the layer in the <see cref="CADImport.CADConverter.Layers"></see> collection</param>
		#endif
		#endregion
		public void SetVisibleLayer(bool visible, int index)
		{
			cadImage.SetLayerVisible(index, visible, lForm.detInvalidate);			
			InitialNewPrintPages();			
			cadPictBox.Invalidate();			
		}
		#region Help
		#if RUSHELP
		/// <summary>
		///     <see cref="CADImport.CADLayer">CADLayer</see>
		/// </summary>
		/// <param name="visible"> </param>
		/// <param name="index">    </param>
		#else
		/// <summary>
		/// Sets <see cref="CADImport.CADLayer.Frozen">CADLayer.Frozen</see> parameter for the layer
		/// by the specified <see cref="CADImport.CADLayer">layer</see> index
		/// </summary>
		/// <param name="visible">Setting value</param>
		/// <param name="index">An index of the layer in the <see cref="CADImport.CADConverter.Layers">layers</see> collection</param>
		#endif
		#endregion
		public void SetFreezeLayer(bool visible, int index)
		{
			cadImage.SetLayerFreeze(index, visible, lForm.detInvalidate);			
			InitialNewPrintPages();
			cadPictBox.Invalidate();			
		}
		#region Help
		#if RUSHELP
		/// <summary>
		///       (<see cref="CADImport.CADLayer">CADLayer</see>)
		/// </summary>
		/// <param name="color">  </param>
		/// <param name="index">   </param>
		#else
		/// <summary>
		/// Sets layer color by the specified <see cref="CADImport.CADLayer">layer</see> index
		/// </summary>
		/// <param name="color">Setting <see cref="System.Drawing.Color">color</see></param>
		/// <param name="index">An index of the layer in the <see cref="CADImport.CADConverter.Layers"></see> collection</param>

		#endif
		#endregion
		public void SetColorLayer(Color color, int index)
		{
			cadImage.SetLayerColor(index, color, lForm.detInvalidate);				
			InitialNewPrintPages();
			cadPictBox.Invalidate();
		}

		private void InitialNewPrintPages()
		{
			this.prtForm.Image = this.cadImage;
			this.prtForm.CreateNewPages();	
		}

		private void SetLayList()
		{
			if((lForm.LayerList.Items.Count != 0)||(cadImage == null))
				return;
			ObjEntity.LayersList = new string[cadImage.LayersCount];			
			Color colorLay;					
			lForm.LayerList.Columns.Add(new ListHeader(ApplicationConstants.headstr1, ApplicationConstants.namestr, 0));
			lForm.LayerList.Columns.Add(new ListHeader(ApplicationConstants.headstr2, ApplicationConstants.visiblestr, 0));
			lForm.LayerList.Columns.Add(new ListHeader(ApplicationConstants.headstr4, ApplicationConstants.freezestr, 0));
			lForm.LayerList.Columns.Add(new ListHeader(ApplicationConstants.headstr3, ApplicationConstants.colorstr, 0));			
			string tmp;
			for(int I = 0; I < cadImage.LayersCount; I++)
			{
				tmp = cadImage.GetLayerName(I);
				colorLay = cadImage.GetLayerColor(I);
				ObjEntity.LayersList[I] = tmp;
				AddRecordToLayerList(tmp, colorLay, cadImage.GetLayerVisible(I), cadImage.GetLayerFreeze(I));				
			}		
			lForm.LayerList.SetAutoSize();
			lForm.LayerList.SelectItemEvent += listItemSelectDel;			
		}

		private void ListSelect(ArrayList item, ListEventSelectArgs e)
		{
			ListItem itm1 =((ListItem)lForm.LayerList.Items[e.ItemIndex]);
			int index = e.ItemIndex / lForm.LayerList.Columns.Count;
			CADImportFace.SelectLayer(index, this.cadImage);
			switch(itm1.ImageIndex)
			{
				case 7:
					itm1.ImageIndex = 8;	
					SetVisibleLayer(false, index);				
					break;
				case 8:
					itm1.ImageIndex = 7;										
					SetVisibleLayer(true, index);
					break;
				case 4:
					itm1.ImageIndex = 3;
					SetFreezeLayer(true, index);
					break;
				case 3:
					itm1.ImageIndex = 4;
					SetFreezeLayer(false, index);
					break;
			}
			if(itm1.DrawColorRect)
			{
				this.dlgSetColor.Color = itm1.BackColor;
				if(this.dlgSetColor.ShowDialog() == DialogResult.OK)
				{
					SetColorLayer(this.dlgSetColor.Color, index);	
					itm1.BackColor = this.dlgSetColor.Color;
					this.lForm.LayerList.InvalidateCell(e.ItemIndex);			
				}
			}
			lForm.LayerList.InvalidateCell(e.ItemIndex);
		}

		#region Help
		/// <summary>
		/// Alternately displays or hides a 3D Orbit tool.
		/// </summary>
		#endregion Help
		public void Go3dOrbit(bool val)
		{
			Orb3D.Visible = val;
			detRMouseDown = false;
			if(val) 
			{
				DoEnableRectangle(false);
				Orb3D.Enable3dOrbit();
			}
			else
				Orb3D.Disable3dOrbit();
			cadPictBox.Invalidate();
		}

		#region Help
		/// <summary>
		/// Resizes the CAD image to fit drawing's bounds.
		/// </summary>
		/// <remarks>This method is invoked when changing layout or working with a 3D Orbit tool.</remarks>
		#endregion Help
		public void DoResize()
		{				
			if(cadImage == null) 
				return;
			float wh = (float)(cadImage.AbsWidth / cadImage.AbsHeight); 
			float new_wh = (float)cadPictBox.ClientRectangle.Width / (float)cadPictBox.ClientRectangle.Height;
			if(cadImage is CADRasterImage)
				visibleArea = new SizeF((float)cadImage.AbsWidth, (float)cadImage.AbsHeight);
			else 
				visibleArea = cadPictBox.Size;
			if(new_wh > wh)
				visibleArea.Width = visibleArea.Height * wh;
			else 
			{
				if(new_wh < wh)
					visibleArea.Height = visibleArea.Width / wh;
				else
					visibleArea = cadPictBox.Size;
			}
			LeftImagePosition = (cadPictBox.ClientRectangle.Width - visibleArea.Width) / 2.0f;
			TopImagePosition = (cadPictBox.ClientRectangle.Height - visibleArea.Height) / 2.0f;				
			cadPictBox.Invalidate();
		}

		#region Help
		/// <summary>
		/// Creates a list of layouts of the CAD image and sets a current layout. 
		/// </summary>
		#endregion Help
		public void ViewLayouts()
		{			
			if(cadImage == null)
				return;
			cbLayouts.Items.Clear();
			for(int i = 0; i < cadImage.LayoutsCount; i++)
				cbLayouts.Items.Add(cadImage.GetLayoutName(i));	
			if(cbLayouts.Items.Count > cadImage.DefaultLayoutIndex)
			{
				cbLayouts.SelectedIndex = cadImage.DefaultLayoutIndex;		
				if(cbLayouts.SelectedIndex >= 0)
					cadImage.SetCurrentLayout(cbLayouts.SelectedIndex);						
			}
		}

		#region Help
		/// <summary>
		/// Changes current layout in accordance with its new index in the list of layouts.
		/// </summary>
		/// <remarks>A list of layouts is located below the toolbar.</remarks>
		#endregion Help
		public void ChangeCurrLayoutIndex()
		{
			cadImage.SetCurrentLayout(cbLayouts.SelectedIndex);
			DoResize();
			ResetScaling();
			if(cbLayouts.SelectedIndex != 0)
			{
				this.tlbLay.Pushed = false;
				this.tlbLay.Enabled = false;
				Orb3D.Visible = false;
				Orb3D.Disable3dOrbit();
			}
			else 
				this.tlbLay.Enabled = true;			
			trvEntity.Nodes.Clear();
			CADImportFace.LoadTreeNodes(trvEntity.Nodes, cadImage);
		}

		#region Help
		/// <summary>
		/// Displays a form in which a user can add or delete the paths to the SHX files.
		/// </summary>
		#endregion Help
		public void AddSHXPaths()
		{
			shxFrm.ShowDialog();
			if(shxFrm.NeedReopen)
				ChangeTypeFont();
		}

		#region Help
		/// <summary>
		/// Shows or hides a panel that contains the entities tree.
		/// </summary>
		#endregion Help
		public void ChangeTreeVisiblity(bool val)
		{			
			if(val)
				CADImportFace.LoadTreeNodes(trvEntity.Nodes, cadImage);
			this.trvPanel.Visible = val;
			this.spTree.Visible = val;
		}

		#region Help
		/// <summary>
		/// Closes a currently open CAD file.
		/// </summary>
		#endregion Help
		public void CloseFile()
		{
			cbLayouts.Items.Clear();
			cadImage.Dispose();
			cadImage = null;
			this.propGrid.SelectedObject = null;
			EnableButton(false);
			this.trvEntity.Nodes.Clear();
			this.cadPictBox.Invalidate();
			this.lForm.LayerList.Clear();
		}

		#region Help
		/// <summary>
		/// Displays a CAD image in all used colors.
		/// </summary>
		#endregion Help
		public void DoNormalColor()
		{
			if(cadImage == null) 
				return;
			cadImage.DrawMode = CADDrawMode.Normal;
			this.drawMode = true;
			cadPictBox.Invalidate();
		}

		#region Help
		/// <summary>
		/// Displays a CAD image in black and white colors.
		/// </summary>
		#endregion Help
		public void DoBlackColor()
		{
			if(cadImage == null) 
				return;
			cadImage.DrawMode = CADDrawMode.Black;
			this.drawMode = false;
			cadPictBox.Invalidate();
		}

		#region Help
		/// <summary>
		/// Alternately changes a boolean value indicating whether arcs and circles in the CAD image 
		/// are drawn with GDI+ drawing methods without linearization. 
		/// </summary>
		#endregion Help
		public void UseWinEllipse()
		{
			this.useWinEllipse = ! this.useWinEllipse;
			cadImage.UseWinEllipse = this.useWinEllipse; 
			cadPictBox.Invalidate();
		}

		#region Help
		/// <summary>
		/// Alternately changes a boolean value that indicates if a thickness of lines is determined by the file data.
		/// </summary>
		#endregion Help
		public void ChangeShowLineWeight()
		{	
			if(! this.showLineWeight)
			{
				if(this.cadImage.UseDoubleBuffering)
				{
					this.useDoubleBuffering = false;
					this.ChangeDoubleBufferingMode();
				}		
			}
			this.showLineWeight = ! this.showLineWeight;
			cadImage.IsShowLineWeight = this.showLineWeight;
			this.cadPictBox.Invalidate();
		}

		private void miSaveFile_Click(object sender, System.EventArgs e)
		{
			SaveAsImage();
		}

		private void MainForm_Deactivate(object sender, System.EventArgs e)
		{
			detRMouseDown = false;
		}

		private void miExit_Click(object sender, System.EventArgs e)
		{
			Close();
		}

		private void miAbout_Click(object sender, System.EventArgs e)
		{
			aboutFrm.ShowDialog();
		}

		private void cbLayouts_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			ChangeCurrLayoutIndex();
		}

		private void miShowShxForm_Click(object sender, System.EventArgs e)
		{
			AddSHXPaths();
			this.ChangeControlState();
		}

		private void MainForm_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			CreateNewSettingsList();
			svSet.SaveOptions(settingsLst);
			#region protect
#if protect
#if floatprotect
			if(Protection.LicenseType == LicenseType.Floating)
			{
				this.floatLicFrm.DisableFloating();
			}
			else
			{
				Protection.CloseApplication();
			}
#else
				Protection.CloseApplication();
#endif
#endif
			#endregion
		}

		private void MainForm_Load(object sender, System.EventArgs e)
		{			
			VisibleAreaSize = cadPictBox.Size;		
			#region protect
#if protect
#if floatprotect
			if(Protection.LicenseType == LicenseType.Floating)			
				this.floatLicFrm.FloatingLicRegister();			
			else				
				Protection.Register();			
#else
				Protection.Register();
#endif
#endif
			#endregion									
			if(openFileName != string.Empty)							
				this.LoadFile(openFileName);												
			this.ChangeControlState();
		}

		private void miBackView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotToView(CADViewDirection.Back);			
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miTopView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotToView(CADViewDirection.Top);			
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miBottomView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotToView(CADViewDirection.Bottom);			
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miLeftView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotToView(CADViewDirection.Left);			
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miRightView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotToView(CADViewDirection.Right);			
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miFrontView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotToView(CADViewDirection.Front);			
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miSWIsometricView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotToView(CADViewDirection.SWIsometric);			
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miSEIsometricView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotToView(CADViewDirection.SEIsometric);			
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miNEIsometricView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotToView(CADViewDirection.NEIsometric);			
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miNWIsometricView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotToView(CADViewDirection.NWIsometric);			
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miInitialView_Click(object sender, System.EventArgs e)
		{
			cadImage.RotDefault();
			this.Orb3D.OnRotate();
			cadPictBox.Invalidate();
		}

		private void miRegistration_Click(object sender, System.EventArgs e)
		{
			#region protect
#if protect
			regFrm.ShowDialog();
#endif
			#endregion protect
		}

		private void trvEntity_AfterCheck(object sender, System.Windows.Forms.TreeViewEventArgs e)
		{			
			CADImportFace.DoCheckTreeNode(trvEntity.Nodes, e.Node, this.cadImage, this.cadPictBox);			
		}

		private void miShowEntityTree_Click(object sender, System.EventArgs e)
		{
			ChangeTreeVisiblity(! this.trvEntity.Visible);
			this.ChangeControlState();
		}

		private void miFitToWindow_Click(object sender, System.EventArgs e)
		{
			ResetScaling();
		}

		private void miCopyAsBMP_Click(object sender, System.EventArgs e)
		{
			this.PutToClipboard();
		}

		private void miClosePicture_Click(object sender, System.EventArgs e)
		{
			CloseFile();
			this.ChangeControlState();
		}

		private void miPrint_Click(object sender, System.EventArgs e)
		{
			try
			{
				cadImage.Print(true, true);
			}
			catch
			{
				return;
			}
		}
		
		private void miDrawNormalColor_Click(object sender, System.EventArgs e)
		{
			DoNormalColor();
			this.ChangeControlState();
		}

		private void miDrawBlackColor_Click(object sender, System.EventArgs e)
		{
			DoBlackColor();
			this.ChangeControlState();
		}

		private void miWhiteBackground_Click(object sender, System.EventArgs e)
		{
			White_Click();
			this.ChangeControlState();
		}

		private void miBlackBackground_Click(object sender, System.EventArgs e)
		{
			Black_Click();
			this.ChangeControlState();
		}

		private void miChangeBackgroundColor_Click(object sender, System.EventArgs e)
		{
			Color_Click();
			this.ChangeControlState();
		}

		private void miArcsSplit_Click(object sender, System.EventArgs e)
		{
			UseWinEllipse();
			this.ChangeControlState();
		}

		private void miShowLineWeight_Click(object sender, System.EventArgs e)
		{
			ChangeShowLineWeight();
			this.ChangeControlState();
		}

		private void miDimShow_Click(object sender, System.EventArgs e)
		{
			ChangeDimensionsVisiblity();
			this.ChangeControlState();
		}

		private void miTextsShow_Click(object sender, System.EventArgs e)
		{
			ChangeTextsVisiblity();
			this.ChangeControlState();
		}

		private void miLayersShow_Click(object sender, System.EventArgs e)
		{
			SetLayList();
			lForm.ShowDialog();
		}

		private void miEnable3DOrbit_Click(object sender, System.EventArgs e)
		{
			Go3dOrbit(! this.Orb3D.Visible);
			this.ChangeControlState();
		}

		private void spTree_SplitterMoved(object sender, System.Windows.Forms.SplitterEventArgs e)
		{
			this.cadPictBox.Invalidate();
		}

		private void LanguageSelect_Click(object sender, System.EventArgs e)
		{
			if(!(sender is MenuItem)) 
				return;
			MenuItem mn = (sender as MenuItem);
			curLngIndex = (byte)mn.Index;
			lngFile = mn.Text + ApplicationConstants.lngextstr; 
			SetAllFormsLanguageSettings();
			SetLNG();
			this.ChangeControlState();
		}
		#region Help
#if RUSHELP
		/// <summary>
		///     
		/// </summary>
		/// <param name="val"> </param>
		/// <param name="index">     </param>
#else
		/// <summary>
		/// Sets specified linguage for the application
		/// </summary>
		/// <param name="val">A language to set</param>
		/// <param name="index">An index of a language in the languages list</param>
#endif
		#endregion
		public void ChangeLanguage(string val, int index)
		{
			curLngIndex = index;
			lngFile = val + ApplicationConstants.lngextstr; 
			SetAllFormsLanguageSettings();
			SetLNG();
			this.ChangeControlState();
		}

		private void SetLNG()
		{
			mlng.LoadLNG(lngFile);
			mlng.RestoreLanguage(this.Controls, this.Menu);
			this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Clear();
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
			this.Text = ApplicationConstants.appnamestr;
			this.Text = mlng.SetLanguage(this.Controls, this.Menu, this.Text);
		}
		
		internal void SetSettings()
		{
			if(settingsLst == null)
				return;
			string tmp; 
			int cn = 0;
			//Language path
			string key = ApplicationConstants.languagepath;
			if(settingsLst.ContainsKey(key))
				this.mlng.Path = Convert.ToString(settingsLst[key]);
			//Language
			key = ApplicationConstants.languagestr;
			if(settingsLst.ContainsKey(key))
				lngFile = (string)settingsLst[key];
			mlng.LoadLNG(lngFile);
			this.Text = mlng.SetLanguage(this.Controls, this.Menu, this.Text);
			//Language ID
			key = ApplicationConstants.languageIDstr;
			if(settingsLst.ContainsKey(key))
				this.curLngIndex = Convert.ToByte(settingsLst[key]);
			//BackgroundColor
			key = ApplicationConstants.backcolorstr;
			tmp = ApplicationConstants.blackstr;
			if(settingsLst.ContainsKey(key))
				tmp = Convert.ToString(settingsLst[key]);
			if(tmp.ToUpper() == ApplicationConstants.blackstr)
				this.Black_Click();
			else 
				this.White_Click();
			//Show entity panel
			key = ApplicationConstants.showentitystr;
			if(settingsLst.ContainsKey(key))
				tmp = Convert.ToString(settingsLst[key]);
			if(tmp.ToUpper() == ApplicationConstants.truestr) 
				this.trvPanel.Visible = true;
			else
				this.trvPanel.Visible = false;
			//Color drawing
			key = ApplicationConstants.drawmodestr;
			if(settingsLst.ContainsKey(key))
				tmp = Convert.ToString(settingsLst[key]);
			if(tmp.ToUpper() == ApplicationConstants.truestr) 
				this.drawMode = true;
			else 
				this.drawMode = false;
			//SHXPathCount
			key = ApplicationConstants.shxpathcnstr;
			if(settingsLst.ContainsKey(key))
				cn = Convert.ToInt32(settingsLst[key]);
			//SHXPaths
			for(int i = 0; i < cn; i++)
			{
				key = string.Format("SHXPath_{0}", (i + 1));
				if(settingsLst.ContainsKey(key))
					this.shxFrm.AddPath(Convert.ToString(settingsLst[key]));
			}
			//First start
			key = ApplicationConstants.installstr;
			if(settingsLst.ContainsKey(key))
			{
				if(CADConst.SearchSHXPaths)
				{
					this.shxFrm.lstDir.Items.Clear();
					this.shxFrm.lstPath.Clear();
					ArrayList vPaths = new ArrayList();
					CADConst.FindAutoCADSHXPaths(vPaths);
					for(int i = 0; i < vPaths.Count; i++)
					{
						tmp = (string)vPaths[i];
						this.shxFrm.lstDir.Items.Add(tmp);
						this.shxFrm.lstPath.Add(tmp, string.Empty);
						CADConst.SHXSearchPaths += CADConst.SHXSearchPaths + tmp + ApplicationConstants.sepstr3;
					}
				}
			}
			#region protect
#if protect			
			key = ApplicationConstants.typelcstr;
			if(settingsLst.ContainsKey(key))
			{
				tmp = (string)settingsLst[key];
#if floatprotect
				if(tmp == ApplicationConstants.floatingstr)
				{
					Protection.LicenseType = LicenseType.Floating;
					key = ApplicationConstants.hoststr;
					if(settingsLst.ContainsKey(key))
					{
						this.floatLicFrm.Host = (string)settingsLst[key];
					}
					key = ApplicationConstants.portstr;
					if(settingsLst.ContainsKey(key))
					{
						this.floatLicFrm.Port = Convert.ToInt32(settingsLst[key]);
					}
					key = ApplicationConstants.appconst;
					if(settingsLst.ContainsKey(key))
					{
						this.floatLicFrm.App = (string)settingsLst[key];
					}
				}
				else
				{
					Protection.LicenseType = LicenseType.Register;
				}
#else
					Protection.LicenseType = LicenseType.Register;
#endif
			}
#endif
			#endregion
		}		

		private void CreateNewSettingsList()
		{
			string tmp;
			settingsLst = new SortedList();			
			settingsLst.Add(ApplicationConstants.languagepath, this.mlng.Path);			
			settingsLst.Add(ApplicationConstants.languagestr, lngFile);			
			settingsLst.Add(ApplicationConstants.languageIDstr, this.curLngIndex);			
			if(cadPictBox.BackColor == Color.Black)
				tmp = ApplicationConstants.blackstr;
			else tmp = ApplicationConstants.whitestr;
			settingsLst.Add(ApplicationConstants.backcolorstr, tmp);			
			settingsLst.Add(ApplicationConstants.showentitystr, this.trvPanel.Visible);			
			settingsLst.Add(ApplicationConstants.drawmodestr, this.drawMode);			
			int cn = this.shxFrm.lstDir.Items.Count;
			settingsLst.Add(ApplicationConstants.shxpathcnstr, this.shxFrm.lstDir.Items.Count);			
			for(int i = 0; i < cn; i++)
			{
				settingsLst.Add(string.Format("SHXPath_{0}", (i + 1)), this.shxFrm.lstDir.Items[i]);
			}
			#region protect
#if protect			
#if floatprotect
			if(Protection.LicenseType == LicenseType.Floating)
			{
				settingsLst.Add(ApplicationConstants.typelcstr, ApplicationConstants.floatingstr);
				settingsLst.Add(ApplicationConstants.hoststr, this.floatLicFrm.Host);
				settingsLst.Add(ApplicationConstants.portstr, this.floatLicFrm.Port);
				settingsLst.Add(ApplicationConstants.appconst, this.floatLicFrm.App);
			}
			else
				settingsLst.Add(ApplicationConstants.typelcstr, ApplicationConstants.registerstr);
#else
				settingsLst.Add(ApplicationConstants.typelcstr, ApplicationConstants.registerstr);
#endif
#endif
			#endregion
			this.optForm.SettingsList = settingsLst;								
		}

		private void miShowOptionsForm_Click(object sender, System.EventArgs e)
		{					
			CreateNewSettingsList();
			if(this.optForm.ShowDialog() == DialogResult.Cancel) return;			
		}

		internal void ReloadLNG()
		{			
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
		}

		internal void ReloadLNG(string val)
		{
			this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Clear();
			mlng.Path = val;
			mlng.LoadLngFileList(this.mainMenu.MenuItems[4].MenuItems[0], new System.EventHandler(LanguageSelect_Click));
			if(this.mainMenu.MenuItems[4].MenuItems[0].MenuItems.Count > this.curLngIndex)
				this.mainMenu.MenuItems[4].MenuItems[0].MenuItems[this.curLngIndex].Checked = true;
		}

		private void miPrintPreview_Click(object sender, System.EventArgs e)
		{
			this.prtForm.TypePage = DrawingSize.Fit;						
			printPrevDlg.Document = prtForm.Print(false);				
			printPrevDlg.ShowDialog();
			if(printPrevDlg.Document != null)
				printPrevDlg.Document.Dispose();
		}

		private void miCustomPrint_Click(object sender, System.EventArgs e)
		{
			prtForm.ShowDialog();
		}

		private void miSaveAsDXF_Click(object sender, System.EventArgs e)
		{
			SaveAsDXF();
		}
		#region Help
		#if RUSHELP
		/// <summary>
		///      dxf
		/// </summary>
		#else
		/// <summary>
		/// Saves opened file to DXF format
		/// </summary>
		#endif
		#endregion
		public void SaveAsDXF()
		{
			if(this.cadImage == null) 
				return;
			if(this.cadImage.FileInf != null)
				this.dlgSaveDXF.FileName = this.cadImage.FileInf.Name.Replace(this.cadImage.FileInf.Extension, string.Empty);
			if(this.dlgSaveDXF.ShowDialog() != DialogResult.OK) 
				return;
			SaveAsDXF(this.dlgSaveDXF.FileName);
		}

		private void SaveAsDXF(string fName)
		{
			#region Export
#if Export
			if(cadImage == null) 
				return;
			if(cadImage is CADRasterImage)
			{
				if(cadImage.FileInf != null)
				if(cadImage.FileInf.Extension.ToUpper() == ApplicationConstants.emfextstr)
					cadImage.EmfConvertToDXF(this.cadImage.FileInf.FullName, this.cadPictBox.Handle, fName);
				return;
			}
			CADtoDXF vExp = new CADtoDXF(cadImage);
			vExp.SaveToFile(fName);
#else
				MessageBox.Show("Not supported in current version!", "CADImport .Net");
#endif
			#endregion Export			
		}

		private void trvEntity_AfterSelect(object sender, System.Windows.Forms.TreeViewEventArgs e)
		{
			CADImportFace.DecodeEntity(e.Node, cadImage, this.cadPictBox, this.ImageScale);			
		}

		private void propGrid_PropertyValueChanged(object s, System.Windows.Forms.PropertyValueChangedEventArgs e)
		{			
			this.cadPictBox.Invalidate();
		}

		private void miFloatLic_Click(object sender, System.EventArgs e)
		{
			#region protect
#if floatprotect
			floatLicFrm.ShowDialog();
#endif
			#endregion
		}

		private void InvalidateImage(object sender, System.EventArgs e)
		{
			this.cadPictBox.Invalidate();
		}		

		private void miOpenFromWeb_Click(object sender, System.EventArgs e)
		{			
			if(this.openFromWebForm.ShowDialog() == DialogResult.OK)
			{
				this.LoadFile(this.openFromWebForm.Path);							
				ChangeControlState();
			}			
		}

		private void ChangeDoubleBufferingMode()
		{
			if(this.cadImage != null)
			{
				if(this.useDoubleBuffering)
				{			
					this.useSelectEntity = false;	
					this.cadImage.ClearSelection();									
					this.clipRectangle.MultySelect = false;		
					this.showLineWeight = false;
					this.tlbSelObject.Pushed = false;
				}
				if(this.cadImage.UseDoubleBuffering != this.useDoubleBuffering)
				{
					this.cadImage.UseDoubleBuffering = this.useDoubleBuffering;					
					this.cadPictBox.Invalidate();
				}
			}			
		}

		internal void CreateNewImage()
		{
			if(cadImage != null)
				cadImage.Dispose();
			ImageScale = 1.0f;
			ImagePreviousScale = 1.0f;
			Position = new PointF();
			cadImage = new CADImage();
			cadImage.SelectionMode = SelectionEntityMode.Enabled;
			this.useDoubleBuffering = false;	
			ChangeDoubleBufferingMode();
			if(cadPictBox.BackColor == Color.White)
				White_Click();
			else 
				Black_Click();
			this.cadImage.InitialNewImage();
			EnableButton(true);
			this.trvEntity.Nodes.Clear();				
			this.DoResize();
			this.cadPictBox.Invalidate();
			ObjEntity.cadImage = cadImage;			
			ObjEntity.propGrid = this.propGrid;		
			cadImage.UseWinEllipse = false;
			prtForm.Image = this.cadImage;		
			cadImage.BackgroundColor = this.cadPictBox.BackColor;
		}

		private void ResizeLayout()
		{
			if(this.cadImage == null) 
				return;
			this.cadImage.GetExtents();
			this.DoResize(); 
		}

		private void cadPictBox_Resize(object sender, System.EventArgs e)
		{
			this.cadPictBox.Invalidate();
		}				

		#region Help
		/// <summary>
		/// debug info
		/// </summary>		
		#endregion
		private void WriteTimeSpan(string debugText, string fileName, DateTime dt1, DateTime dt2)
		{
			TimeSpan sp = dt2 - dt1;
			StreamWriter wr1 = new StreamWriter(fileName, true);
			wr1.WriteLine(string.Format("[{0}] {1}-{2}-{3}-{4}", debugText, sp.Hours, sp.Minutes, sp.Seconds, sp.Milliseconds));
			wr1.Close();
		}		
	}

	internal abstract class ApplicationConstants
	{
		public static readonly string defaultstr;
		public static readonly string languagepath;
		public static readonly string loadfilestr;
		public static readonly string msgBoxDebugCaption;
		public static readonly string sepstr;
		public static readonly string notsupportedstr;
		public static readonly string notsupportedextstr;
		public static readonly string appnamestr;
		public static readonly string sepstr2;
		public static readonly string jpgextstr;
		public static readonly string bmpextstr;
		public static readonly string tiffextstr;
		public static readonly string gifextstr;
		public static readonly string emfextstr;
		public static readonly string wmfextstr;
		public static readonly string pngextstr;			
		public static readonly string dxfextstr;
		public static readonly string lngextstr;
		public static readonly string languagestr;
		public static readonly string languageIDstr;
		public static readonly string backcolorstr;
		public static readonly string blackstr;
		public static readonly string showentitystr;
		public static readonly string drawmodestr;
		public static readonly string truestr;
		public static readonly string shxpathcnstr;
		public static readonly string installstr;
		public static readonly string sepstr3;
		public static readonly string typelcstr;
		public static readonly string floatingstr;
		public static readonly string hoststr;
		public static readonly string portstr;
		public static readonly string appconst;
		public static readonly string blackstr2;
		public static readonly string whitestr;
		public static readonly string registerstr;
		public static readonly string headstr1;
		public static readonly string headstr2;
		public static readonly string headstr3;
		public static readonly string headstr4;
		public static readonly string namestr;
		public static readonly string visiblestr;
		public static readonly string freezestr;
		public static readonly string colorstr;			

		static ApplicationConstants()
		{
			defaultstr = "Default";
			languagepath = "LanguagePath";
			loadfilestr = "Loading file...";
			msgBoxDebugCaption = "Debug application message";
			sepstr = " - ";
			notsupportedstr = "not supported";
			notsupportedextstr = "Not supported in current version!";
			appnamestr = "CADImportNet Demo";
			sepstr2 = " : ";			
			jpgextstr = ".JPG";
			bmpextstr = ".BMP";
			tiffextstr = ".TIFF";
			gifextstr = ".GIF";
			emfextstr = ".EMF";
			wmfextstr = ".WMF";
			pngextstr = ".PNG";			
			dxfextstr = ".DXF";
			lngextstr = ".lng";
			languagestr = "Language";
			languageIDstr = "LanguageID";
			backcolorstr = "BackgroundColor";
			blackstr = "BLACK";
			showentitystr = "ShowEntity";
			drawmodestr = "drawMode";
			truestr = "TRUE";
			shxpathcnstr = "SHXPathCount";
			installstr = "Install";
			sepstr3 = ";";
			typelcstr = "Type_license";
			floatingstr = "floating";
			hoststr = "Host";
			portstr = "Port";
			appconst = "Application";
			blackstr2 = "Black";
			whitestr = "White";
			registerstr = "register";
			headstr1 = "Head1";
			headstr2 = "Head2";
			headstr3 = "Head3";
			headstr4 = "Head4";
			namestr = "Name";
			visiblestr = "Visible";
			freezestr = "Freeze";
			colorstr = "Color";			
		}
	}

	#region Documentation
	#if Documentation
	#region Help
	/// <summary>
	/// <p>The <B>Viewer</B> application demonstrates main features of the <B>Viewer</B> library. All tools necessary for viewing, manipulating, 
	/// converting, saving CAD images can be accessed both from the main menu and from the toolbar. All entities loaded from a CAD file 
	/// are shown in the entities tree on the left side of the viewer. In the entities tree any shown entity can be turned off or turned on.</p>
	/// </summary>
	#endregion Help
	public class NamespaceDoc
	{

	}
	#endif
	#endregion	
}
